# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class Personalizedtxt2imgQueryModelTrainJobListResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.Personalizedtxt2imgQueryModelTrainJobListResponseBodyData] = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['data'].append(k1.to_map() if k1 else None)

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('data') is not None:
            for k1 in m.get('data'):
                temp_model = main_models.Personalizedtxt2imgQueryModelTrainJobListResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class Personalizedtxt2imgQueryModelTrainJobListResponseBodyData(DaraModel):
    def __init__(
        self,
        create_time: str = None,
        id: str = None,
        image_url: List[str] = None,
        inference_image_count: int = None,
        inference_job_list: List[main_models.Personalizedtxt2imgQueryModelTrainJobListResponseBodyDataInferenceJobList] = None,
        job_status: str = None,
        job_train_progress: float = None,
        model_id: str = None,
        name: str = None,
        object_type: str = None,
    ):
        self.create_time = create_time
        self.id = id
        self.image_url = image_url
        self.inference_image_count = inference_image_count
        self.inference_job_list = inference_job_list
        self.job_status = job_status
        self.job_train_progress = job_train_progress
        self.model_id = model_id
        self.name = name
        self.object_type = object_type

    def validate(self):
        if self.inference_job_list:
            for v1 in self.inference_job_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.id is not None:
            result['id'] = self.id

        if self.image_url is not None:
            result['imageUrl'] = self.image_url

        if self.inference_image_count is not None:
            result['inferenceImageCount'] = self.inference_image_count

        result['inferenceJobList'] = []
        if self.inference_job_list is not None:
            for k1 in self.inference_job_list:
                result['inferenceJobList'].append(k1.to_map() if k1 else None)

        if self.job_status is not None:
            result['jobStatus'] = self.job_status

        if self.job_train_progress is not None:
            result['jobTrainProgress'] = self.job_train_progress

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.name is not None:
            result['name'] = self.name

        if self.object_type is not None:
            result['objectType'] = self.object_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('imageUrl') is not None:
            self.image_url = m.get('imageUrl')

        if m.get('inferenceImageCount') is not None:
            self.inference_image_count = m.get('inferenceImageCount')

        self.inference_job_list = []
        if m.get('inferenceJobList') is not None:
            for k1 in m.get('inferenceJobList'):
                temp_model = main_models.Personalizedtxt2imgQueryModelTrainJobListResponseBodyDataInferenceJobList()
                self.inference_job_list.append(temp_model.from_map(k1))

        if m.get('jobStatus') is not None:
            self.job_status = m.get('jobStatus')

        if m.get('jobTrainProgress') is not None:
            self.job_train_progress = m.get('jobTrainProgress')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('objectType') is not None:
            self.object_type = m.get('objectType')

        return self

class Personalizedtxt2imgQueryModelTrainJobListResponseBodyDataInferenceJobList(DaraModel):
    def __init__(
        self,
        create_time: str = None,
        id: str = None,
        job_status: str = None,
        job_train_progress: float = None,
        model_id: str = None,
        prompt_id: str = None,
        result_image_url: List[str] = None,
    ):
        self.create_time = create_time
        self.id = id
        self.job_status = job_status
        self.job_train_progress = job_train_progress
        self.model_id = model_id
        self.prompt_id = prompt_id
        self.result_image_url = result_image_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.id is not None:
            result['id'] = self.id

        if self.job_status is not None:
            result['jobStatus'] = self.job_status

        if self.job_train_progress is not None:
            result['jobTrainProgress'] = self.job_train_progress

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.prompt_id is not None:
            result['promptId'] = self.prompt_id

        if self.result_image_url is not None:
            result['resultImageUrl'] = self.result_image_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('jobStatus') is not None:
            self.job_status = m.get('jobStatus')

        if m.get('jobTrainProgress') is not None:
            self.job_train_progress = m.get('jobTrainProgress')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('promptId') is not None:
            self.prompt_id = m.get('promptId')

        if m.get('resultImageUrl') is not None:
            self.result_image_url = m.get('resultImageUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Any

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ObservationChartsDTO(DaraModel):
    def __init__(
        self,
        call_volume: List[main_models.TimeSeriesPointDTO] = None,
        concurrency: List[main_models.TimeSeriesPointDTO] = None,
        qpm: List[main_models.TimeSeriesPointDTO] = None,
        response_time: List[main_models.TimeSeriesPointDTO] = None,
        success_rate: List[main_models.ObservationChartsDTOSuccessRate] = None,
        tpm: List[main_models.TimeSeriesPointDTO] = None,
    ):
        self.call_volume = call_volume
        self.concurrency = concurrency
        self.qpm = qpm
        self.response_time = response_time
        self.success_rate = success_rate
        self.tpm = tpm

    def validate(self):
        if self.call_volume:
            for v1 in self.call_volume:
                 if v1:
                    v1.validate()
        if self.concurrency:
            for v1 in self.concurrency:
                 if v1:
                    v1.validate()
        if self.qpm:
            for v1 in self.qpm:
                 if v1:
                    v1.validate()
        if self.response_time:
            for v1 in self.response_time:
                 if v1:
                    v1.validate()
        if self.success_rate:
            for v1 in self.success_rate:
                 if v1:
                    v1.validate()
        if self.tpm:
            for v1 in self.tpm:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['callVolume'] = []
        if self.call_volume is not None:
            for k1 in self.call_volume:
                result['callVolume'].append(k1.to_map() if k1 else None)

        result['concurrency'] = []
        if self.concurrency is not None:
            for k1 in self.concurrency:
                result['concurrency'].append(k1.to_map() if k1 else None)

        result['qpm'] = []
        if self.qpm is not None:
            for k1 in self.qpm:
                result['qpm'].append(k1.to_map() if k1 else None)

        result['responseTime'] = []
        if self.response_time is not None:
            for k1 in self.response_time:
                result['responseTime'].append(k1.to_map() if k1 else None)

        result['successRate'] = []
        if self.success_rate is not None:
            for k1 in self.success_rate:
                result['successRate'].append(k1.to_map() if k1 else None)

        result['tpm'] = []
        if self.tpm is not None:
            for k1 in self.tpm:
                result['tpm'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.call_volume = []
        if m.get('callVolume') is not None:
            for k1 in m.get('callVolume'):
                temp_model = main_models.TimeSeriesPointDTO()
                self.call_volume.append(temp_model.from_map(k1))

        self.concurrency = []
        if m.get('concurrency') is not None:
            for k1 in m.get('concurrency'):
                temp_model = main_models.TimeSeriesPointDTO()
                self.concurrency.append(temp_model.from_map(k1))

        self.qpm = []
        if m.get('qpm') is not None:
            for k1 in m.get('qpm'):
                temp_model = main_models.TimeSeriesPointDTO()
                self.qpm.append(temp_model.from_map(k1))

        self.response_time = []
        if m.get('responseTime') is not None:
            for k1 in m.get('responseTime'):
                temp_model = main_models.TimeSeriesPointDTO()
                self.response_time.append(temp_model.from_map(k1))

        self.success_rate = []
        if m.get('successRate') is not None:
            for k1 in m.get('successRate'):
                temp_model = main_models.ObservationChartsDTOSuccessRate()
                self.success_rate.append(temp_model.from_map(k1))

        self.tpm = []
        if m.get('tpm') is not None:
            for k1 in m.get('tpm'):
                temp_model = main_models.TimeSeriesPointDTO()
                self.tpm.append(temp_model.from_map(k1))

        return self



class ObservationChartsDTOSuccessRate(DaraModel):
    def __init__(
        self,
        label: str = None,
        timestamp: str = None,
        value: Any = None,
    ):
        self.label = label
        self.timestamp = timestamp
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.label is not None:
            result['label'] = self.label

        if self.timestamp is not None:
            result['timestamp'] = self.timestamp

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('label') is not None:
            self.label = m.get('label')

        if m.get('timestamp') is not None:
            self.timestamp = m.get('timestamp')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class AITeacherExpansionPracticeTaskGenerateResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.AITeacherExpansionPracticeTaskGenerateResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.AITeacherExpansionPracticeTaskGenerateResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class AITeacherExpansionPracticeTaskGenerateResponseBodyData(DaraModel):
    def __init__(
        self,
        background_description: str = None,
        role_set: main_models.AITeacherExpansionPracticeTaskGenerateResponseBodyDataRoleSet = None,
        start_sentence: str = None,
        task_content: List[main_models.AITeacherExpansionPracticeTaskGenerateResponseBodyDataTaskContent] = None,
        task_type: str = None,
    ):
        self.background_description = background_description
        self.role_set = role_set
        self.start_sentence = start_sentence
        self.task_content = task_content
        self.task_type = task_type

    def validate(self):
        if self.role_set:
            self.role_set.validate()
        if self.task_content:
            for v1 in self.task_content:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.background_description is not None:
            result['backgroundDescription'] = self.background_description

        if self.role_set is not None:
            result['roleSet'] = self.role_set.to_map()

        if self.start_sentence is not None:
            result['startSentence'] = self.start_sentence

        result['taskContent'] = []
        if self.task_content is not None:
            for k1 in self.task_content:
                result['taskContent'].append(k1.to_map() if k1 else None)

        if self.task_type is not None:
            result['taskType'] = self.task_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('backgroundDescription') is not None:
            self.background_description = m.get('backgroundDescription')

        if m.get('roleSet') is not None:
            temp_model = main_models.AITeacherExpansionPracticeTaskGenerateResponseBodyDataRoleSet()
            self.role_set = temp_model.from_map(m.get('roleSet'))

        if m.get('startSentence') is not None:
            self.start_sentence = m.get('startSentence')

        self.task_content = []
        if m.get('taskContent') is not None:
            for k1 in m.get('taskContent'):
                temp_model = main_models.AITeacherExpansionPracticeTaskGenerateResponseBodyDataTaskContent()
                self.task_content.append(temp_model.from_map(k1))

        if m.get('taskType') is not None:
            self.task_type = m.get('taskType')

        return self

class AITeacherExpansionPracticeTaskGenerateResponseBodyDataTaskContent(DaraModel):
    def __init__(
        self,
        assistant: str = None,
        user: str = None,
    ):
        self.assistant = assistant
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assistant is not None:
            result['assistant'] = self.assistant

        if self.user is not None:
            result['user'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assistant') is not None:
            self.assistant = m.get('assistant')

        if m.get('user') is not None:
            self.user = m.get('user')

        return self

class AITeacherExpansionPracticeTaskGenerateResponseBodyDataRoleSet(DaraModel):
    def __init__(
        self,
        assistant: str = None,
        user: str = None,
    ):
        self.assistant = assistant
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assistant is not None:
            result['assistant'] = self.assistant

        if self.user is not None:
            result['user'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assistant') is not None:
            self.assistant = m.get('assistant')

        if m.get('user') is not None:
            self.user = m.get('user')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class AITeacherExpansionPracticeTaskGenerateRequest(DaraModel):
    def __init__(
        self,
        grade: str = None,
        key_sentences: List[str] = None,
        key_words: List[str] = None,
        learning_object: str = None,
        text_content: str = None,
        textbook: str = None,
        topic: str = None,
        user_id: str = None,
    ):
        # This parameter is required.
        self.grade = grade
        self.key_sentences = key_sentences
        self.key_words = key_words
        self.learning_object = learning_object
        # This parameter is required.
        self.text_content = text_content
        self.textbook = textbook
        # This parameter is required.
        self.topic = topic
        # This parameter is required.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.grade is not None:
            result['grade'] = self.grade

        if self.key_sentences is not None:
            result['keySentences'] = self.key_sentences

        if self.key_words is not None:
            result['keyWords'] = self.key_words

        if self.learning_object is not None:
            result['learningObject'] = self.learning_object

        if self.text_content is not None:
            result['textContent'] = self.text_content

        if self.textbook is not None:
            result['textbook'] = self.textbook

        if self.topic is not None:
            result['topic'] = self.topic

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('grade') is not None:
            self.grade = m.get('grade')

        if m.get('keySentences') is not None:
            self.key_sentences = m.get('keySentences')

        if m.get('keyWords') is not None:
            self.key_words = m.get('keyWords')

        if m.get('learningObject') is not None:
            self.learning_object = m.get('learningObject')

        if m.get('textContent') is not None:
            self.text_content = m.get('textContent')

        if m.get('textbook') is not None:
            self.textbook = m.get('textbook')

        if m.get('topic') is not None:
            self.topic = m.get('topic')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class CostQueryModelsDTO(DaraModel):
    def __init__(
        self,
        columns: List[main_models.MetricDefRespDTO] = None,
        id_field: str = None,
        name_field: str = None,
        rows: List[main_models.ModelRowDTO] = None,
    ):
        self.columns = columns
        self.id_field = id_field
        self.name_field = name_field
        self.rows = rows

    def validate(self):
        if self.columns:
            for v1 in self.columns:
                 if v1:
                    v1.validate()
        if self.rows:
            for v1 in self.rows:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['columns'] = []
        if self.columns is not None:
            for k1 in self.columns:
                result['columns'].append(k1.to_map() if k1 else None)

        if self.id_field is not None:
            result['idField'] = self.id_field

        if self.name_field is not None:
            result['nameField'] = self.name_field

        result['rows'] = []
        if self.rows is not None:
            for k1 in self.rows:
                result['rows'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.columns = []
        if m.get('columns') is not None:
            for k1 in m.get('columns'):
                temp_model = main_models.MetricDefRespDTO()
                self.columns.append(temp_model.from_map(k1))

        if m.get('idField') is not None:
            self.id_field = m.get('idField')

        if m.get('nameField') is not None:
            self.name_field = m.get('nameField')

        self.rows = []
        if m.get('rows') is not None:
            for k1 in m.get('rows'):
                temp_model = main_models.ModelRowDTO()
                self.rows.append(temp_model.from_map(k1))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ConversationUpdateCmd(DaraModel):
    def __init__(
        self,
        chat_data: str = None,
        message_count: int = None,
        model_ids: str = None,
        title: str = None,
    ):
        self.chat_data = chat_data
        self.message_count = message_count
        self.model_ids = model_ids
        self.title = title

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.chat_data is not None:
            result['chatData'] = self.chat_data

        if self.message_count is not None:
            result['messageCount'] = self.message_count

        if self.model_ids is not None:
            result['modelIds'] = self.model_ids

        if self.title is not None:
            result['title'] = self.title

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('chatData') is not None:
            self.chat_data = m.get('chatData')

        if m.get('messageCount') is not None:
            self.message_count = m.get('messageCount')

        if m.get('modelIds') is not None:
            self.model_ids = m.get('modelIds')

        if m.get('title') is not None:
            self.title = m.get('title')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModelRouterQueryCostTrendMetricsRequest(DaraModel):
    def __init__(
        self,
        client_id: int = None,
        end_time: int = None,
        granularity: str = None,
        max_results: int = None,
        model_types: str = None,
        next_token: str = None,
        start_time: int = None,
    ):
        self.client_id = client_id
        # This parameter is required.
        self.end_time = end_time
        self.granularity = granularity
        self.max_results = max_results
        self.model_types = model_types
        # nextToken
        self.next_token = next_token
        # This parameter is required.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.granularity is not None:
            result['granularity'] = self.granularity

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.model_types is not None:
            result['modelTypes'] = self.model_types

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.start_time is not None:
            result['startTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('granularity') is not None:
            self.granularity = m.get('granularity')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('modelTypes') is not None:
            self.model_types = m.get('modelTypes')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ModelRouterQueryClientDiscountLogsResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.ModelRouterQueryClientDiscountLogsResponseBodyData] = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        max_results: int = None,
        next_token: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        # maxResults
        self.max_results = max_results
        # nextToken
        self.next_token = next_token
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['data'].append(k1.to_map() if k1 else None)

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('data') is not None:
            for k1 in m.get('data'):
                temp_model = main_models.ModelRouterQueryClientDiscountLogsResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class ModelRouterQueryClientDiscountLogsResponseBodyData(DaraModel):
    def __init__(
        self,
        client_id: int = None,
        delete_tag: int = None,
        discount: float = None,
        effective_time: str = None,
        expire_time: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        remark: str = None,
    ):
        self.client_id = client_id
        self.delete_tag = delete_tag
        self.discount = discount
        self.effective_time = effective_time
        self.expire_time = expire_time
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.id = id
        self.remark = remark

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.delete_tag is not None:
            result['deleteTag'] = self.delete_tag

        if self.discount is not None:
            result['discount'] = self.discount

        if self.effective_time is not None:
            result['effectiveTime'] = self.effective_time

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.id is not None:
            result['id'] = self.id

        if self.remark is not None:
            result['remark'] = self.remark

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('deleteTag') is not None:
            self.delete_tag = m.get('deleteTag')

        if m.get('discount') is not None:
            self.discount = m.get('discount')

        if m.get('effectiveTime') is not None:
            self.effective_time = m.get('effectiveTime')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('remark') is not None:
            self.remark = m.get('remark')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Personalizedtxt2imgAddInferenceJobCmd(DaraModel):
    def __init__(
        self,
        image_number: int = None,
        model_id: str = None,
        prompt: str = None,
        seed: int = None,
    ):
        self.image_number = image_number
        # This parameter is required.
        self.model_id = model_id
        # This parameter is required.
        self.prompt = prompt
        self.seed = seed

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.image_number is not None:
            result['imageNumber'] = self.image_number

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.prompt is not None:
            result['prompt'] = self.prompt

        if self.seed is not None:
            result['seed'] = self.seed

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('imageNumber') is not None:
            self.image_number = m.get('imageNumber')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('prompt') is not None:
            self.prompt = m.get('prompt')

        if m.get('seed') is not None:
            self.seed = m.get('seed')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ExecuteAITeacherSyncDialogueTranslateRequest(DaraModel):
    def __init__(
        self,
        dialogue_tasks: List[main_models.ExecuteAITeacherSyncDialogueTranslateRequestDialogueTasks] = None,
        records: List[main_models.ExecuteAITeacherSyncDialogueTranslateRequestRecords] = None,
        user_id: str = None,
    ):
        # This parameter is required.
        self.dialogue_tasks = dialogue_tasks
        self.records = records
        # This parameter is required.
        self.user_id = user_id

    def validate(self):
        if self.dialogue_tasks:
            for v1 in self.dialogue_tasks:
                 if v1:
                    v1.validate()
        if self.records:
            for v1 in self.records:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['dialogueTasks'] = []
        if self.dialogue_tasks is not None:
            for k1 in self.dialogue_tasks:
                result['dialogueTasks'].append(k1.to_map() if k1 else None)

        result['records'] = []
        if self.records is not None:
            for k1 in self.records:
                result['records'].append(k1.to_map() if k1 else None)

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.dialogue_tasks = []
        if m.get('dialogueTasks') is not None:
            for k1 in m.get('dialogueTasks'):
                temp_model = main_models.ExecuteAITeacherSyncDialogueTranslateRequestDialogueTasks()
                self.dialogue_tasks.append(temp_model.from_map(k1))

        self.records = []
        if m.get('records') is not None:
            for k1 in m.get('records'):
                temp_model = main_models.ExecuteAITeacherSyncDialogueTranslateRequestRecords()
                self.records.append(temp_model.from_map(k1))

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self

class ExecuteAITeacherSyncDialogueTranslateRequestRecords(DaraModel):
    def __init__(
        self,
        content: str = None,
        is_off_topic_control: bool = None,
        is_on_topic: bool = None,
        order: int = None,
        role: str = None,
    ):
        # This parameter is required.
        self.content = content
        self.is_off_topic_control = is_off_topic_control
        self.is_on_topic = is_on_topic
        # This parameter is required.
        self.order = order
        # This parameter is required.
        self.role = role

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.content is not None:
            result['content'] = self.content

        if self.is_off_topic_control is not None:
            result['isOffTopicControl'] = self.is_off_topic_control

        if self.is_on_topic is not None:
            result['isOnTopic'] = self.is_on_topic

        if self.order is not None:
            result['order'] = self.order

        if self.role is not None:
            result['role'] = self.role

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('content') is not None:
            self.content = m.get('content')

        if m.get('isOffTopicControl') is not None:
            self.is_off_topic_control = m.get('isOffTopicControl')

        if m.get('isOnTopic') is not None:
            self.is_on_topic = m.get('isOnTopic')

        if m.get('order') is not None:
            self.order = m.get('order')

        if m.get('role') is not None:
            self.role = m.get('role')

        return self

class ExecuteAITeacherSyncDialogueTranslateRequestDialogueTasks(DaraModel):
    def __init__(
        self,
        assistant: str = None,
        assistant_translate: str = None,
        order: int = None,
        user: str = None,
    ):
        # This parameter is required.
        self.assistant = assistant
        self.assistant_translate = assistant_translate
        # This parameter is required.
        self.order = order
        # This parameter is required.
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assistant is not None:
            result['assistant'] = self.assistant

        if self.assistant_translate is not None:
            result['assistantTranslate'] = self.assistant_translate

        if self.order is not None:
            result['order'] = self.order

        if self.user is not None:
            result['user'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assistant') is not None:
            self.assistant = m.get('assistant')

        if m.get('assistantTranslate') is not None:
            self.assistant_translate = m.get('assistantTranslate')

        if m.get('order') is not None:
            self.order = m.get('order')

        if m.get('user') is not None:
            self.user = m.get('user')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Any

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ListTextbookAssistantBookDirectoriesResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.ListTextbookAssistantBookDirectoriesResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        # Id of the request
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyData(DaraModel):
    def __init__(
        self,
        directory_tree: List[main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTree] = None,
        edition_info: main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataEditionInfo = None,
    ):
        self.directory_tree = directory_tree
        self.edition_info = edition_info

    def validate(self):
        if self.directory_tree:
            for v1 in self.directory_tree:
                 if v1:
                    v1.validate()
        if self.edition_info:
            self.edition_info.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['directoryTree'] = []
        if self.directory_tree is not None:
            for k1 in self.directory_tree:
                result['directoryTree'].append(k1.to_map() if k1 else None)

        if self.edition_info is not None:
            result['editionInfo'] = self.edition_info.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.directory_tree = []
        if m.get('directoryTree') is not None:
            for k1 in m.get('directoryTree'):
                temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTree()
                self.directory_tree.append(temp_model.from_map(k1))

        if m.get('editionInfo') is not None:
            temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataEditionInfo()
            self.edition_info = temp_model.from_map(m.get('editionInfo'))

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataEditionInfo(DaraModel):
    def __init__(
        self,
        book_id: str = None,
        book_volume: str = None,
        edition: str = None,
        grade: str = None,
        impression: str = None,
        isbn: str = None,
        publisher: str = None,
        subject: str = None,
        version: str = None,
    ):
        self.book_id = book_id
        self.book_volume = book_volume
        self.edition = edition
        self.grade = grade
        self.impression = impression
        self.isbn = isbn
        self.publisher = publisher
        self.subject = subject
        self.version = version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.book_id is not None:
            result['bookId'] = self.book_id

        if self.book_volume is not None:
            result['bookVolume'] = self.book_volume

        if self.edition is not None:
            result['edition'] = self.edition

        if self.grade is not None:
            result['grade'] = self.grade

        if self.impression is not None:
            result['impression'] = self.impression

        if self.isbn is not None:
            result['isbn'] = self.isbn

        if self.publisher is not None:
            result['publisher'] = self.publisher

        if self.subject is not None:
            result['subject'] = self.subject

        if self.version is not None:
            result['version'] = self.version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bookId') is not None:
            self.book_id = m.get('bookId')

        if m.get('bookVolume') is not None:
            self.book_volume = m.get('bookVolume')

        if m.get('edition') is not None:
            self.edition = m.get('edition')

        if m.get('grade') is not None:
            self.grade = m.get('grade')

        if m.get('impression') is not None:
            self.impression = m.get('impression')

        if m.get('isbn') is not None:
            self.isbn = m.get('isbn')

        if m.get('publisher') is not None:
            self.publisher = m.get('publisher')

        if m.get('subject') is not None:
            self.subject = m.get('subject')

        if m.get('version') is not None:
            self.version = m.get('version')

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTree(DaraModel):
    def __init__(
        self,
        directory_id: str = None,
        directory_name: str = None,
        topic: List[main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeTopic] = None,
        unit: List[main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnit] = None,
    ):
        self.directory_id = directory_id
        self.directory_name = directory_name
        self.topic = topic
        self.unit = unit

    def validate(self):
        if self.topic:
            for v1 in self.topic:
                 if v1:
                    v1.validate()
        if self.unit:
            for v1 in self.unit:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.directory_id is not None:
            result['directoryId'] = self.directory_id

        if self.directory_name is not None:
            result['directoryName'] = self.directory_name

        result['topic'] = []
        if self.topic is not None:
            for k1 in self.topic:
                result['topic'].append(k1.to_map() if k1 else None)

        result['unit'] = []
        if self.unit is not None:
            for k1 in self.unit:
                result['unit'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('directoryId') is not None:
            self.directory_id = m.get('directoryId')

        if m.get('directoryName') is not None:
            self.directory_name = m.get('directoryName')

        self.topic = []
        if m.get('topic') is not None:
            for k1 in m.get('topic'):
                temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeTopic()
                self.topic.append(temp_model.from_map(k1))

        self.unit = []
        if m.get('unit') is not None:
            for k1 in m.get('unit'):
                temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnit()
                self.unit.append(temp_model.from_map(k1))

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnit(DaraModel):
    def __init__(
        self,
        directory_id: str = None,
        directory_name: str = None,
        section: List[main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSection] = None,
        topic: List[main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitTopic] = None,
    ):
        self.directory_id = directory_id
        self.directory_name = directory_name
        self.section = section
        self.topic = topic

    def validate(self):
        if self.section:
            for v1 in self.section:
                 if v1:
                    v1.validate()
        if self.topic:
            for v1 in self.topic:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.directory_id is not None:
            result['directoryId'] = self.directory_id

        if self.directory_name is not None:
            result['directoryName'] = self.directory_name

        result['section'] = []
        if self.section is not None:
            for k1 in self.section:
                result['section'].append(k1.to_map() if k1 else None)

        result['topic'] = []
        if self.topic is not None:
            for k1 in self.topic:
                result['topic'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('directoryId') is not None:
            self.directory_id = m.get('directoryId')

        if m.get('directoryName') is not None:
            self.directory_name = m.get('directoryName')

        self.section = []
        if m.get('section') is not None:
            for k1 in m.get('section'):
                temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSection()
                self.section.append(temp_model.from_map(k1))

        self.topic = []
        if m.get('topic') is not None:
            for k1 in m.get('topic'):
                temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitTopic()
                self.topic.append(temp_model.from_map(k1))

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitTopic(DaraModel):
    def __init__(
        self,
        label_id: str = None,
        label_name: str = None,
    ):
        self.label_id = label_id
        self.label_name = label_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.label_id is not None:
            result['labelId'] = self.label_id

        if self.label_name is not None:
            result['labelName'] = self.label_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('labelId') is not None:
            self.label_id = m.get('labelId')

        if m.get('labelName') is not None:
            self.label_name = m.get('labelName')

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSection(DaraModel):
    def __init__(
        self,
        children: Any = None,
        directory_id: str = None,
        directory_name: str = None,
        topic: List[main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSectionTopic] = None,
    ):
        self.children = children
        self.directory_id = directory_id
        self.directory_name = directory_name
        self.topic = topic

    def validate(self):
        if self.topic:
            for v1 in self.topic:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.children is not None:
            result['children'] = self.children

        if self.directory_id is not None:
            result['directoryId'] = self.directory_id

        if self.directory_name is not None:
            result['directoryName'] = self.directory_name

        result['topic'] = []
        if self.topic is not None:
            for k1 in self.topic:
                result['topic'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('children') is not None:
            self.children = m.get('children')

        if m.get('directoryId') is not None:
            self.directory_id = m.get('directoryId')

        if m.get('directoryName') is not None:
            self.directory_name = m.get('directoryName')

        self.topic = []
        if m.get('topic') is not None:
            for k1 in m.get('topic'):
                temp_model = main_models.ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSectionTopic()
                self.topic.append(temp_model.from_map(k1))

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSectionTopic(DaraModel):
    def __init__(
        self,
        label_id: str = None,
        label_name: str = None,
    ):
        self.label_id = label_id
        self.label_name = label_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.label_id is not None:
            result['labelId'] = self.label_id

        if self.label_name is not None:
            result['labelName'] = self.label_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('labelId') is not None:
            self.label_id = m.get('labelId')

        if m.get('labelName') is not None:
            self.label_name = m.get('labelName')

        return self

class ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeTopic(DaraModel):
    def __init__(
        self,
        label_id: str = None,
        label_name: str = None,
    ):
        self.label_id = label_id
        self.label_name = label_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.label_id is not None:
            result['labelId'] = self.label_id

        if self.label_name is not None:
            result['labelName'] = self.label_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('labelId') is not None:
            self.label_id = m.get('labelId')

        if m.get('labelName') is not None:
            self.label_name = m.get('labelName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class QueryApplicationAccessIdResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.QueryApplicationAccessIdResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.QueryApplicationAccessIdResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class QueryApplicationAccessIdResponseBodyData(DaraModel):
    def __init__(
        self,
        application_access_id: str = None,
        application_access_secret: str = None,
    ):
        self.application_access_id = application_access_id
        self.application_access_secret = application_access_secret

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_access_id is not None:
            result['applicationAccessId'] = self.application_access_id

        if self.application_access_secret is not None:
            result['applicationAccessSecret'] = self.application_access_secret

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationAccessId') is not None:
            self.application_access_id = m.get('applicationAccessId')

        if m.get('applicationAccessSecret') is not None:
            self.application_access_secret = m.get('applicationAccessSecret')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ClientUpdateCmd(DaraModel):
    def __init__(
        self,
        address: str = None,
        allowed_models: str = None,
        contact: str = None,
        name: str = None,
        remark: str = None,
        status: int = None,
    ):
        self.address = address
        self.allowed_models = allowed_models
        self.contact = contact
        self.name = name
        self.remark = remark
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.address is not None:
            result['address'] = self.address

        if self.allowed_models is not None:
            result['allowedModels'] = self.allowed_models

        if self.contact is not None:
            result['contact'] = self.contact

        if self.name is not None:
            result['name'] = self.name

        if self.remark is not None:
            result['remark'] = self.remark

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('address') is not None:
            self.address = m.get('address')

        if m.get('allowedModels') is not None:
            self.allowed_models = m.get('allowedModels')

        if m.get('contact') is not None:
            self.contact = m.get('contact')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('remark') is not None:
            self.remark = m.get('remark')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._aliyun_console_service_info_dto import AliyunConsoleServiceInfoDTO
from ._api_key_create_cmd import ApiKeyCreateCmd
from ._api_key_dto import ApiKeyDTO
from ._api_key_decrypted_dto import ApiKeyDecryptedDTO
from ._api_key_list_qry import ApiKeyListQry
from ._api_key_update_cmd import ApiKeyUpdateCmd
from ._billing_cost_breakdown_resp_dto import BillingCostBreakdownRespDTO
from ._billing_cost_breakdown_row_dto import BillingCostBreakdownRowDTO
from ._client_create_cmd import ClientCreateCmd
from ._client_dto import ClientDTO
from ._client_list_qry import ClientListQry
from ._client_tree_dto import ClientTreeDTO
from ._client_update_cmd import ClientUpdateCmd
from ._conversation_create_cmd import ConversationCreateCmd
from ._conversation_dto import ConversationDTO
from ._conversation_list_qry import ConversationListQry
from ._conversation_update_cmd import ConversationUpdateCmd
from ._cost_model_detail_resp_dto import CostModelDetailRespDTO
from ._cost_model_detail_row_dto import CostModelDetailRowDTO
from ._cost_query_models_dto import CostQueryModelsDTO
from ._cost_query_trend_dto import CostQueryTrendDTO
from ._cost_tab_dto import CostTabDTO
from ._metric_def_resp_dto import MetricDefRespDTO
from ._metric_kvpair_dto import MetricKVPairDTO
from ._metric_value_dto import MetricValueDTO
from ._model_create_cmd import ModelCreateCmd
from ._model_dto import ModelDTO
from ._model_list_qry import ModelListQry
from ._model_metrics_dto import ModelMetricsDTO
from ._model_row_dto import ModelRowDTO
from ._model_update_cmd import ModelUpdateCmd
from ._observation_charts_dto import ObservationChartsDTO
from ._observation_log_list_qry import ObservationLogListQry
from ._observation_qry import ObservationQry
from ._open_api_multi_response import OpenApiMultiResponse
from ._open_api_single_response import OpenApiSingleResponse
from ._oral_evaluation_statistics_calls_count_request import OralEvaluationStatisticsCallsCountRequest
from ._oral_evaluation_statistics_calls_count_response import OralEvaluationStatisticsCallsCountResponse
from ._oral_evaluation_statistics_concurrent_count_request import OralEvaluationStatisticsConcurrentCountRequest
from ._oral_evaluation_statistics_concurrent_count_response import OralEvaluationStatisticsConcurrentCountResponse
from ._oral_evaluation_statistics_error_count_request import OralEvaluationStatisticsErrorCountRequest
from ._oral_evaluation_statistics_error_count_response import OralEvaluationStatisticsErrorCountResponse
from ._org_init_result_dto import OrgInitResultDTO
from ._paid_resource_dto import PaidResourceDTO
from ._paid_resource_qry import PaidResourceQry
from ._personalizedtxt_2img_add_inference_job_cmd import Personalizedtxt2imgAddInferenceJobCmd
from ._personalizedtxt_2img_add_model_train_job_cmd import Personalizedtxt2imgAddModelTrainJobCmd
from ._personalizedtxt_2img_inference_job_info_dto import Personalizedtxt2imgInferenceJobInfoDTO
from ._personalizedtxt_2img_model_train_job_info_dto import Personalizedtxt2imgModelTrainJobInfoDTO
from ._request_log_dto import RequestLogDTO
from ._request_log_list_qry import RequestLogListQry
from ._time_series_point_dto import TimeSeriesPointDTO
from ._trend_point_dto import TrendPointDTO
from ._usage_breakdown_resp_dto import UsageBreakdownRespDTO
from ._usage_breakdown_row_dto import UsageBreakdownRowDTO
from ._usage_info_dto import UsageInfoDTO
from ._aiteacher_expansion_practice_task_generate_request import AITeacherExpansionPracticeTaskGenerateRequest
from ._aiteacher_expansion_practice_task_generate_response_body import AITeacherExpansionPracticeTaskGenerateResponseBody
from ._aiteacher_expansion_practice_task_generate_response import AITeacherExpansionPracticeTaskGenerateResponse
from ._aiteacher_sync_practice_task_generate_request import AITeacherSyncPracticeTaskGenerateRequest
from ._aiteacher_sync_practice_task_generate_response_body import AITeacherSyncPracticeTaskGenerateResponseBody
from ._aiteacher_sync_practice_task_generate_response import AITeacherSyncPracticeTaskGenerateResponse
from ._aliyun_console_open_api_query_aliyun_console_servcie_list_response_body import AliyunConsoleOpenApiQueryAliyunConsoleServcieListResponseBody
from ._aliyun_console_open_api_query_aliyun_console_servcie_list_response import AliyunConsoleOpenApiQueryAliyunConsoleServcieListResponse
from ._aliyun_console_open_api_query_aliyun_console_service_list_response_body import AliyunConsoleOpenApiQueryAliyunConsoleServiceListResponseBody
from ._aliyun_console_open_api_query_aliyun_console_service_list_response import AliyunConsoleOpenApiQueryAliyunConsoleServiceListResponse
from ._aliyun_console_open_api_query_paid_resource_request import AliyunConsoleOpenApiQueryPaidResourceRequest
from ._aliyun_console_open_api_query_paid_resource_response_body import AliyunConsoleOpenApiQueryPaidResourceResponseBody
from ._aliyun_console_open_api_query_paid_resource_response import AliyunConsoleOpenApiQueryPaidResourceResponse
from ._count_oral_evaluation_statistics_calls_request import CountOralEvaluationStatisticsCallsRequest
from ._count_oral_evaluation_statistics_calls_response_body import CountOralEvaluationStatisticsCallsResponseBody
from ._count_oral_evaluation_statistics_calls_response import CountOralEvaluationStatisticsCallsResponse
from ._count_oral_evaluation_statistics_concurrent_request import CountOralEvaluationStatisticsConcurrentRequest
from ._count_oral_evaluation_statistics_concurrent_response_body import CountOralEvaluationStatisticsConcurrentResponseBody
from ._count_oral_evaluation_statistics_concurrent_response import CountOralEvaluationStatisticsConcurrentResponse
from ._count_oral_evaluation_statistics_error_request import CountOralEvaluationStatisticsErrorRequest
from ._count_oral_evaluation_statistics_error_response_body import CountOralEvaluationStatisticsErrorResponseBody
from ._count_oral_evaluation_statistics_error_response import CountOralEvaluationStatisticsErrorResponse
from ._create_access_warrant_request import CreateAccessWarrantRequest
from ._create_access_warrant_response_body import CreateAccessWarrantResponseBody
from ._create_access_warrant_response import CreateAccessWarrantResponse
from ._create_project_request import CreateProjectRequest
from ._create_project_response_body import CreateProjectResponseBody
from ._create_project_response import CreateProjectResponse
from ._execute_aiteacher_chinese_composition_tutoring_workflow_run_request import ExecuteAITeacherChineseCompositionTutoringWorkflowRunRequest
from ._execute_aiteacher_chinese_composition_tutoring_workflow_run_response_body import ExecuteAITeacherChineseCompositionTutoringWorkflowRunResponseBody
from ._execute_aiteacher_chinese_composition_tutoring_workflow_run_response import ExecuteAITeacherChineseCompositionTutoringWorkflowRunResponse
from ._execute_aiteacher_english_composition_tutoring_workflow_run_request import ExecuteAITeacherEnglishCompositionTutoringWorkflowRunRequest
from ._execute_aiteacher_english_composition_tutoring_workflow_run_response_body import ExecuteAITeacherEnglishCompositionTutoringWorkflowRunResponseBody
from ._execute_aiteacher_english_composition_tutoring_workflow_run_response import ExecuteAITeacherEnglishCompositionTutoringWorkflowRunResponse
from ._execute_aiteacher_english_paraphrase_chat_message_request import ExecuteAITeacherEnglishParaphraseChatMessageRequest
from ._execute_aiteacher_english_paraphrase_chat_message_response_body import ExecuteAITeacherEnglishParaphraseChatMessageResponseBody
from ._execute_aiteacher_english_paraphrase_chat_message_response import ExecuteAITeacherEnglishParaphraseChatMessageResponse
from ._execute_aiteacher_expansion_dialogue_request import ExecuteAITeacherExpansionDialogueRequest
from ._execute_aiteacher_expansion_dialogue_response_body import ExecuteAITeacherExpansionDialogueResponseBody
from ._execute_aiteacher_expansion_dialogue_response import ExecuteAITeacherExpansionDialogueResponse
from ._execute_aiteacher_expansion_dialogue_refine_request import ExecuteAITeacherExpansionDialogueRefineRequest
from ._execute_aiteacher_expansion_dialogue_refine_response_body import ExecuteAITeacherExpansionDialogueRefineResponseBody
from ._execute_aiteacher_expansion_dialogue_refine_response import ExecuteAITeacherExpansionDialogueRefineResponse
from ._execute_aiteacher_expansion_dialogue_translate_request import ExecuteAITeacherExpansionDialogueTranslateRequest
from ._execute_aiteacher_expansion_dialogue_translate_response_body import ExecuteAITeacherExpansionDialogueTranslateResponseBody
from ._execute_aiteacher_expansion_dialogue_translate_response import ExecuteAITeacherExpansionDialogueTranslateResponse
from ._execute_aiteacher_grammar_check_request import ExecuteAITeacherGrammarCheckRequest
from ._execute_aiteacher_grammar_check_response_body import ExecuteAITeacherGrammarCheckResponseBody
from ._execute_aiteacher_grammar_check_response import ExecuteAITeacherGrammarCheckResponse
from ._execute_aiteacher_sync_dialogue_request import ExecuteAITeacherSyncDialogueRequest
from ._execute_aiteacher_sync_dialogue_response_body import ExecuteAITeacherSyncDialogueResponseBody
from ._execute_aiteacher_sync_dialogue_response import ExecuteAITeacherSyncDialogueResponse
from ._execute_aiteacher_sync_dialogue_translate_request import ExecuteAITeacherSyncDialogueTranslateRequest
from ._execute_aiteacher_sync_dialogue_translate_response_body import ExecuteAITeacherSyncDialogueTranslateResponseBody
from ._execute_aiteacher_sync_dialogue_translate_response import ExecuteAITeacherSyncDialogueTranslateResponse
from ._execute_textbook_assistant_dialogue_request import ExecuteTextbookAssistantDialogueRequest
from ._execute_textbook_assistant_dialogue_response_body import ExecuteTextbookAssistantDialogueResponseBody
from ._execute_textbook_assistant_dialogue_response import ExecuteTextbookAssistantDialogueResponse
from ._execute_textbook_assistant_difficulty_request import ExecuteTextbookAssistantDifficultyRequest
from ._execute_textbook_assistant_difficulty_response_body import ExecuteTextbookAssistantDifficultyResponseBody
from ._execute_textbook_assistant_difficulty_response import ExecuteTextbookAssistantDifficultyResponse
from ._execute_textbook_assistant_grammar_check_request import ExecuteTextbookAssistantGrammarCheckRequest
from ._execute_textbook_assistant_grammar_check_response_body import ExecuteTextbookAssistantGrammarCheckResponseBody
from ._execute_textbook_assistant_grammar_check_response import ExecuteTextbookAssistantGrammarCheckResponse
from ._execute_textbook_assistant_refine_by_context_request import ExecuteTextbookAssistantRefineByContextRequest
from ._execute_textbook_assistant_refine_by_context_response_body import ExecuteTextbookAssistantRefineByContextResponseBody
from ._execute_textbook_assistant_refine_by_context_response import ExecuteTextbookAssistantRefineByContextResponse
from ._execute_textbook_assistant_retry_conversation_request import ExecuteTextbookAssistantRetryConversationRequest
from ._execute_textbook_assistant_retry_conversation_response_body import ExecuteTextbookAssistantRetryConversationResponseBody
from ._execute_textbook_assistant_retry_conversation_response import ExecuteTextbookAssistantRetryConversationResponse
from ._execute_textbook_assistant_sse_dialogue_request import ExecuteTextbookAssistantSseDialogueRequest
from ._execute_textbook_assistant_sse_dialogue_response_body import ExecuteTextbookAssistantSseDialogueResponseBody
from ._execute_textbook_assistant_sse_dialogue_response import ExecuteTextbookAssistantSseDialogueResponse
from ._execute_textbook_assistant_start_conversation_request import ExecuteTextbookAssistantStartConversationRequest
from ._execute_textbook_assistant_start_conversation_response_body import ExecuteTextbookAssistantStartConversationResponseBody
from ._execute_textbook_assistant_start_conversation_response import ExecuteTextbookAssistantStartConversationResponse
from ._execute_textbook_assistant_suggestion_request import ExecuteTextbookAssistantSuggestionRequest
from ._execute_textbook_assistant_suggestion_response_body import ExecuteTextbookAssistantSuggestionResponseBody
from ._execute_textbook_assistant_suggestion_response import ExecuteTextbookAssistantSuggestionResponse
from ._execute_textbook_assistant_translate_request import ExecuteTextbookAssistantTranslateRequest
from ._execute_textbook_assistant_translate_response_body import ExecuteTextbookAssistantTranslateResponseBody
from ._execute_textbook_assistant_translate_response import ExecuteTextbookAssistantTranslateResponse
from ._get_aiteacher_expansion_dialogue_suggestion_request import GetAITeacherExpansionDialogueSuggestionRequest
from ._get_aiteacher_expansion_dialogue_suggestion_response_body import GetAITeacherExpansionDialogueSuggestionResponseBody
from ._get_aiteacher_expansion_dialogue_suggestion_response import GetAITeacherExpansionDialogueSuggestionResponse
from ._get_aiteacher_sync_dialogue_suggestion_request import GetAITeacherSyncDialogueSuggestionRequest
from ._get_aiteacher_sync_dialogue_suggestion_response_body import GetAITeacherSyncDialogueSuggestionResponseBody
from ._get_aiteacher_sync_dialogue_suggestion_response import GetAITeacherSyncDialogueSuggestionResponse
from ._get_textbook_assistant_token_request import GetTextbookAssistantTokenRequest
from ._get_textbook_assistant_token_response_body import GetTextbookAssistantTokenResponseBody
from ._get_textbook_assistant_token_response import GetTextbookAssistantTokenResponse
from ._list_textbook_assistant_article_details_request import ListTextbookAssistantArticleDetailsRequest
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBody
from ._list_textbook_assistant_article_details_response import ListTextbookAssistantArticleDetailsResponse
from ._list_textbook_assistant_articles_request import ListTextbookAssistantArticlesRequest
from ._list_textbook_assistant_articles_response_body import ListTextbookAssistantArticlesResponseBody
from ._list_textbook_assistant_articles_response import ListTextbookAssistantArticlesResponse
from ._list_textbook_assistant_book_directories_request import ListTextbookAssistantBookDirectoriesRequest
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBody
from ._list_textbook_assistant_book_directories_response import ListTextbookAssistantBookDirectoriesResponse
from ._list_textbook_assistant_books_request import ListTextbookAssistantBooksRequest
from ._list_textbook_assistant_books_response_body import ListTextbookAssistantBooksResponseBody
from ._list_textbook_assistant_books_response import ListTextbookAssistantBooksResponse
from ._list_textbook_assistant_grade_volumes_request import ListTextbookAssistantGradeVolumesRequest
from ._list_textbook_assistant_grade_volumes_response_body import ListTextbookAssistantGradeVolumesResponseBody
from ._list_textbook_assistant_grade_volumes_response import ListTextbookAssistantGradeVolumesResponse
from ._list_textbook_assistant_scene_details_request import ListTextbookAssistantSceneDetailsRequest
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBody
from ._list_textbook_assistant_scene_details_response import ListTextbookAssistantSceneDetailsResponse
from ._model_router_billing_cost_tabs_request import ModelRouterBillingCostTabsRequest
from ._model_router_billing_cost_tabs_response_body import ModelRouterBillingCostTabsResponseBody
from ._model_router_billing_cost_tabs_response import ModelRouterBillingCostTabsResponse
from ._model_router_chat_completions_request import ModelRouterChatCompletionsRequest
from ._model_router_chat_completions_response_body import ModelRouterChatCompletionsResponseBody
from ._model_router_chat_completions_response import ModelRouterChatCompletionsResponse
from ._model_router_copy_api_key_response_body import ModelRouterCopyApiKeyResponseBody
from ._model_router_copy_api_key_response import ModelRouterCopyApiKeyResponse
from ._model_router_create_api_key_request import ModelRouterCreateApiKeyRequest
from ._model_router_create_api_key_response_body import ModelRouterCreateApiKeyResponseBody
from ._model_router_create_api_key_response import ModelRouterCreateApiKeyResponse
from ._model_router_create_billing_rule_request import ModelRouterCreateBillingRuleRequest
from ._model_router_create_billing_rule_response_body import ModelRouterCreateBillingRuleResponseBody
from ._model_router_create_billing_rule_response import ModelRouterCreateBillingRuleResponse
from ._model_router_create_client_request import ModelRouterCreateClientRequest
from ._model_router_create_client_response_body import ModelRouterCreateClientResponseBody
from ._model_router_create_client_response import ModelRouterCreateClientResponse
from ._model_router_create_conversation_request import ModelRouterCreateConversationRequest
from ._model_router_create_conversation_response_body import ModelRouterCreateConversationResponseBody
from ._model_router_create_conversation_response import ModelRouterCreateConversationResponse
from ._model_router_create_model_request import ModelRouterCreateModelRequest
from ._model_router_create_model_response_body import ModelRouterCreateModelResponseBody
from ._model_router_create_model_response import ModelRouterCreateModelResponse
from ._model_router_delete_api_key_response_body import ModelRouterDeleteApiKeyResponseBody
from ._model_router_delete_api_key_response import ModelRouterDeleteApiKeyResponse
from ._model_router_delete_client_response_body import ModelRouterDeleteClientResponseBody
from ._model_router_delete_client_response import ModelRouterDeleteClientResponse
from ._model_router_delete_conversation_response_body import ModelRouterDeleteConversationResponseBody
from ._model_router_delete_conversation_response import ModelRouterDeleteConversationResponse
from ._model_router_delete_model_response_body import ModelRouterDeleteModelResponseBody
from ._model_router_delete_model_response import ModelRouterDeleteModelResponse
from ._model_router_query_api_key_response_body import ModelRouterQueryApiKeyResponseBody
from ._model_router_query_api_key_response import ModelRouterQueryApiKeyResponse
from ._model_router_query_api_key_list_request import ModelRouterQueryApiKeyListRequest
from ._model_router_query_api_key_list_response_body import ModelRouterQueryApiKeyListResponseBody
from ._model_router_query_api_key_list_response import ModelRouterQueryApiKeyListResponse
from ._model_router_query_billing_cost_breakdown_request import ModelRouterQueryBillingCostBreakdownRequest
from ._model_router_query_billing_cost_breakdown_response_body import ModelRouterQueryBillingCostBreakdownResponseBody
from ._model_router_query_billing_cost_breakdown_response import ModelRouterQueryBillingCostBreakdownResponse
from ._model_router_query_billing_rule_list_request import ModelRouterQueryBillingRuleListRequest
from ._model_router_query_billing_rule_list_response_body import ModelRouterQueryBillingRuleListResponseBody
from ._model_router_query_billing_rule_list_response import ModelRouterQueryBillingRuleListResponse
from ._model_router_query_client_discount_logs_request import ModelRouterQueryClientDiscountLogsRequest
from ._model_router_query_client_discount_logs_response_body import ModelRouterQueryClientDiscountLogsResponseBody
from ._model_router_query_client_discount_logs_response import ModelRouterQueryClientDiscountLogsResponse
from ._model_router_query_client_list_request import ModelRouterQueryClientListRequest
from ._model_router_query_client_list_response_body import ModelRouterQueryClientListResponseBody
from ._model_router_query_client_list_response import ModelRouterQueryClientListResponse
from ._model_router_query_client_tree_request import ModelRouterQueryClientTreeRequest
from ._model_router_query_client_tree_response_body import ModelRouterQueryClientTreeResponseBody
from ._model_router_query_client_tree_response import ModelRouterQueryClientTreeResponse
from ._model_router_query_conversation_response_body import ModelRouterQueryConversationResponseBody
from ._model_router_query_conversation_response import ModelRouterQueryConversationResponse
from ._model_router_query_conversation_list_request import ModelRouterQueryConversationListRequest
from ._model_router_query_conversation_list_response_body import ModelRouterQueryConversationListResponseBody
from ._model_router_query_conversation_list_response import ModelRouterQueryConversationListResponse
from ._model_router_query_cost_model_detail_request import ModelRouterQueryCostModelDetailRequest
from ._model_router_query_cost_model_detail_response_body import ModelRouterQueryCostModelDetailResponseBody
from ._model_router_query_cost_model_detail_response import ModelRouterQueryCostModelDetailResponse
from ._model_router_query_cost_model_list_request import ModelRouterQueryCostModelListRequest
from ._model_router_query_cost_model_list_response_body import ModelRouterQueryCostModelListResponseBody
from ._model_router_query_cost_model_list_response import ModelRouterQueryCostModelListResponse
from ._model_router_query_cost_overview_metrics_request import ModelRouterQueryCostOverviewMetricsRequest
from ._model_router_query_cost_overview_metrics_response_body import ModelRouterQueryCostOverviewMetricsResponseBody
from ._model_router_query_cost_overview_metrics_response import ModelRouterQueryCostOverviewMetricsResponse
from ._model_router_query_cost_trend_metrics_request import ModelRouterQueryCostTrendMetricsRequest
from ._model_router_query_cost_trend_metrics_response_body import ModelRouterQueryCostTrendMetricsResponseBody
from ._model_router_query_cost_trend_metrics_response import ModelRouterQueryCostTrendMetricsResponse
from ._model_router_query_model_response_body import ModelRouterQueryModelResponseBody
from ._model_router_query_model_response import ModelRouterQueryModelResponse
from ._model_router_query_model_list_request import ModelRouterQueryModelListRequest
from ._model_router_query_model_list_response_body import ModelRouterQueryModelListResponseBody
from ._model_router_query_model_list_response import ModelRouterQueryModelListResponse
from ._model_router_query_nacos_providers_request import ModelRouterQueryNacosProvidersRequest
from ._model_router_query_nacos_providers_response_body import ModelRouterQueryNacosProvidersResponseBody
from ._model_router_query_nacos_providers_response import ModelRouterQueryNacosProvidersResponse
from ._model_router_query_nacos_tags_request import ModelRouterQueryNacosTagsRequest
from ._model_router_query_nacos_tags_response_body import ModelRouterQueryNacosTagsResponseBody
from ._model_router_query_nacos_tags_response import ModelRouterQueryNacosTagsResponse
from ._model_router_query_observation_charts_request import ModelRouterQueryObservationChartsRequest
from ._model_router_query_observation_charts_response_body import ModelRouterQueryObservationChartsResponseBody
from ._model_router_query_observation_charts_response import ModelRouterQueryObservationChartsResponse
from ._model_router_query_observation_logs_request import ModelRouterQueryObservationLogsRequest
from ._model_router_query_observation_logs_response_body import ModelRouterQueryObservationLogsResponseBody
from ._model_router_query_observation_logs_response import ModelRouterQueryObservationLogsResponse
from ._model_router_query_observation_metrics_request import ModelRouterQueryObservationMetricsRequest
from ._model_router_query_observation_metrics_response_body import ModelRouterQueryObservationMetricsResponseBody
from ._model_router_query_observation_metrics_response import ModelRouterQueryObservationMetricsResponse
from ._model_router_query_usage_breakdown_request import ModelRouterQueryUsageBreakdownRequest
from ._model_router_query_usage_breakdown_response_body import ModelRouterQueryUsageBreakdownResponseBody
from ._model_router_query_usage_breakdown_response import ModelRouterQueryUsageBreakdownResponse
from ._model_router_update_billing_rule_request import ModelRouterUpdateBillingRuleRequest
from ._model_router_update_billing_rule_response_body import ModelRouterUpdateBillingRuleResponseBody
from ._model_router_update_billing_rule_response import ModelRouterUpdateBillingRuleResponse
from ._model_router_update_client_request import ModelRouterUpdateClientRequest
from ._model_router_update_client_response_body import ModelRouterUpdateClientResponseBody
from ._model_router_update_client_response import ModelRouterUpdateClientResponse
from ._model_router_update_conversation_request import ModelRouterUpdateConversationRequest
from ._model_router_update_conversation_response_body import ModelRouterUpdateConversationResponseBody
from ._model_router_update_conversation_response import ModelRouterUpdateConversationResponse
from ._model_router_update_model_request import ModelRouterUpdateModelRequest
from ._model_router_update_model_response_body import ModelRouterUpdateModelResponseBody
from ._model_router_update_model_response import ModelRouterUpdateModelResponse
from ._personalized_text_to_image_add_inference_job_request import PersonalizedTextToImageAddInferenceJobRequest
from ._personalized_text_to_image_add_inference_job_response_body import PersonalizedTextToImageAddInferenceJobResponseBody
from ._personalized_text_to_image_add_inference_job_response import PersonalizedTextToImageAddInferenceJobResponse
from ._personalized_text_to_image_query_image_asset_request import PersonalizedTextToImageQueryImageAssetRequest
from ._personalized_text_to_image_query_image_asset_response import PersonalizedTextToImageQueryImageAssetResponse
from ._personalized_text_to_image_query_pre_model_inference_job_info_request import PersonalizedTextToImageQueryPreModelInferenceJobInfoRequest
from ._personalized_text_to_image_query_pre_model_inference_job_info_response_body import PersonalizedTextToImageQueryPreModelInferenceJobInfoResponseBody
from ._personalized_text_to_image_query_pre_model_inference_job_info_response import PersonalizedTextToImageQueryPreModelInferenceJobInfoResponse
from ._personalizedtxt_2img_add_inference_job_request import Personalizedtxt2imgAddInferenceJobRequest
from ._personalizedtxt_2img_add_inference_job_response_body import Personalizedtxt2imgAddInferenceJobResponseBody
from ._personalizedtxt_2img_add_inference_job_response import Personalizedtxt2imgAddInferenceJobResponse
from ._personalizedtxt_2img_add_model_train_job_request import Personalizedtxt2imgAddModelTrainJobRequest
from ._personalizedtxt_2img_add_model_train_job_response_body import Personalizedtxt2imgAddModelTrainJobResponseBody
from ._personalizedtxt_2img_add_model_train_job_response import Personalizedtxt2imgAddModelTrainJobResponse
from ._personalizedtxt_2img_query_image_asset_request import Personalizedtxt2imgQueryImageAssetRequest
from ._personalizedtxt_2img_query_image_asset_response import Personalizedtxt2imgQueryImageAssetResponse
from ._personalizedtxt_2img_query_inference_job_info_request import Personalizedtxt2imgQueryInferenceJobInfoRequest
from ._personalizedtxt_2img_query_inference_job_info_response_body import Personalizedtxt2imgQueryInferenceJobInfoResponseBody
from ._personalizedtxt_2img_query_inference_job_info_response import Personalizedtxt2imgQueryInferenceJobInfoResponse
from ._personalizedtxt_2img_query_model_train_job_list_response_body import Personalizedtxt2imgQueryModelTrainJobListResponseBody
from ._personalizedtxt_2img_query_model_train_job_list_response import Personalizedtxt2imgQueryModelTrainJobListResponse
from ._personalizedtxt_2img_query_model_train_status_request import Personalizedtxt2imgQueryModelTrainStatusRequest
from ._personalizedtxt_2img_query_model_train_status_response_body import Personalizedtxt2imgQueryModelTrainStatusResponseBody
from ._personalizedtxt_2img_query_model_train_status_response import Personalizedtxt2imgQueryModelTrainStatusResponse
from ._query_application_access_id_request import QueryApplicationAccessIdRequest
from ._query_application_access_id_response_body import QueryApplicationAccessIdResponseBody
from ._query_application_access_id_response import QueryApplicationAccessIdResponse
from ._query_project_request import QueryProjectRequest
from ._query_project_response_body import QueryProjectResponseBody
from ._query_project_response import QueryProjectResponse
from ._query_project_list_response_body import QueryProjectListResponseBody
from ._query_project_list_response import QueryProjectListResponse
from ._query_purchased_service_response_body import QueryPurchasedServiceResponseBody
from ._query_purchased_service_response import QueryPurchasedServiceResponse
from ._update_project_request import UpdateProjectRequest
from ._update_project_response_body import UpdateProjectResponseBody
from ._update_project_response import UpdateProjectResponse
from ._observation_charts_dto import ObservationChartsDTOSuccessRate
from ._open_api_multi_response import OpenApiMultiResponseDataInferenceJobList
from ._open_api_multi_response import OpenApiMultiResponseData
from ._open_api_single_response import OpenApiSingleResponseData
from ._oral_evaluation_statistics_calls_count_response import OralEvaluationStatisticsCallsCountResponseProjectDataApplicationDataData
from ._oral_evaluation_statistics_calls_count_response import OralEvaluationStatisticsCallsCountResponseProjectDataApplicationData
from ._oral_evaluation_statistics_calls_count_response import OralEvaluationStatisticsCallsCountResponseProjectData
from ._oral_evaluation_statistics_concurrent_count_response import OralEvaluationStatisticsConcurrentCountResponseProjectDataApplicationDataData
from ._oral_evaluation_statistics_concurrent_count_response import OralEvaluationStatisticsConcurrentCountResponseProjectDataApplicationData
from ._oral_evaluation_statistics_concurrent_count_response import OralEvaluationStatisticsConcurrentCountResponseProjectData
from ._oral_evaluation_statistics_error_count_response import OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataDataData
from ._oral_evaluation_statistics_error_count_response import OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataData
from ._oral_evaluation_statistics_error_count_response import OralEvaluationStatisticsErrorCountResponseProjectDataApplicationData
from ._oral_evaluation_statistics_error_count_response import OralEvaluationStatisticsErrorCountResponseProjectData
from ._aiteacher_expansion_practice_task_generate_response_body import AITeacherExpansionPracticeTaskGenerateResponseBodyDataRoleSet
from ._aiteacher_expansion_practice_task_generate_response_body import AITeacherExpansionPracticeTaskGenerateResponseBodyDataTaskContent
from ._aiteacher_expansion_practice_task_generate_response_body import AITeacherExpansionPracticeTaskGenerateResponseBodyData
from ._aiteacher_sync_practice_task_generate_response_body import AITeacherSyncPracticeTaskGenerateResponseBodyDataTaskContent
from ._aiteacher_sync_practice_task_generate_response_body import AITeacherSyncPracticeTaskGenerateResponseBodyData
from ._aliyun_console_open_api_query_aliyun_console_servcie_list_response_body import AliyunConsoleOpenApiQueryAliyunConsoleServcieListResponseBodyData
from ._create_access_warrant_response_body import CreateAccessWarrantResponseBodyData
from ._create_project_response_body import CreateProjectResponseBodyDataProjectAppsApplicationAccessIds
from ._create_project_response_body import CreateProjectResponseBodyDataProjectApps
from ._create_project_response_body import CreateProjectResponseBodyDataProjectSDK
from ._create_project_response_body import CreateProjectResponseBodyData
from ._execute_aiteacher_expansion_dialogue_request import ExecuteAITeacherExpansionDialogueRequestDialogueTasks
from ._execute_aiteacher_expansion_dialogue_request import ExecuteAITeacherExpansionDialogueRequestRecords
from ._execute_aiteacher_expansion_dialogue_request import ExecuteAITeacherExpansionDialogueRequestRoleInfo
from ._execute_aiteacher_expansion_dialogue_response_body import ExecuteAITeacherExpansionDialogueResponseBodyData
from ._execute_aiteacher_expansion_dialogue_refine_request import ExecuteAITeacherExpansionDialogueRefineRequestDialogueTasks
from ._execute_aiteacher_expansion_dialogue_refine_request import ExecuteAITeacherExpansionDialogueRefineRequestRecords
from ._execute_aiteacher_expansion_dialogue_refine_request import ExecuteAITeacherExpansionDialogueRefineRequestRoleInfo
from ._execute_aiteacher_expansion_dialogue_refine_response_body import ExecuteAITeacherExpansionDialogueRefineResponseBodyData
from ._execute_aiteacher_expansion_dialogue_translate_request import ExecuteAITeacherExpansionDialogueTranslateRequestDialogueTasks
from ._execute_aiteacher_expansion_dialogue_translate_request import ExecuteAITeacherExpansionDialogueTranslateRequestRecords
from ._execute_aiteacher_expansion_dialogue_translate_request import ExecuteAITeacherExpansionDialogueTranslateRequestRoleInfo
from ._execute_aiteacher_expansion_dialogue_translate_response_body import ExecuteAITeacherExpansionDialogueTranslateResponseBodyData
from ._execute_aiteacher_grammar_check_response_body import ExecuteAITeacherGrammarCheckResponseBodyData
from ._execute_aiteacher_sync_dialogue_request import ExecuteAITeacherSyncDialogueRequestDialogueTasks
from ._execute_aiteacher_sync_dialogue_request import ExecuteAITeacherSyncDialogueRequestRecords
from ._execute_aiteacher_sync_dialogue_response_body import ExecuteAITeacherSyncDialogueResponseBodyData
from ._execute_aiteacher_sync_dialogue_translate_request import ExecuteAITeacherSyncDialogueTranslateRequestDialogueTasks
from ._execute_aiteacher_sync_dialogue_translate_request import ExecuteAITeacherSyncDialogueTranslateRequestRecords
from ._execute_aiteacher_sync_dialogue_translate_response_body import ExecuteAITeacherSyncDialogueTranslateResponseBodyData
from ._execute_textbook_assistant_dialogue_response_body import ExecuteTextbookAssistantDialogueResponseBodyDataResult
from ._execute_textbook_assistant_dialogue_response_body import ExecuteTextbookAssistantDialogueResponseBodyData
from ._execute_textbook_assistant_difficulty_response_body import ExecuteTextbookAssistantDifficultyResponseBodyDataResult
from ._execute_textbook_assistant_difficulty_response_body import ExecuteTextbookAssistantDifficultyResponseBodyData
from ._execute_textbook_assistant_grammar_check_response_body import ExecuteTextbookAssistantGrammarCheckResponseBodyDataResult
from ._execute_textbook_assistant_grammar_check_response_body import ExecuteTextbookAssistantGrammarCheckResponseBodyData
from ._execute_textbook_assistant_refine_by_context_response_body import ExecuteTextbookAssistantRefineByContextResponseBodyDataResult
from ._execute_textbook_assistant_refine_by_context_response_body import ExecuteTextbookAssistantRefineByContextResponseBodyData
from ._execute_textbook_assistant_retry_conversation_response_body import ExecuteTextbookAssistantRetryConversationResponseBodyDataResult
from ._execute_textbook_assistant_retry_conversation_response_body import ExecuteTextbookAssistantRetryConversationResponseBodyData
from ._execute_textbook_assistant_sse_dialogue_response_body import ExecuteTextbookAssistantSseDialogueResponseBodyData
from ._execute_textbook_assistant_start_conversation_response_body import ExecuteTextbookAssistantStartConversationResponseBodyDataResult
from ._execute_textbook_assistant_start_conversation_response_body import ExecuteTextbookAssistantStartConversationResponseBodyData
from ._execute_textbook_assistant_suggestion_response_body import ExecuteTextbookAssistantSuggestionResponseBodyDataResult
from ._execute_textbook_assistant_suggestion_response_body import ExecuteTextbookAssistantSuggestionResponseBodyData
from ._execute_textbook_assistant_translate_response_body import ExecuteTextbookAssistantTranslateResponseBodyDataResult
from ._execute_textbook_assistant_translate_response_body import ExecuteTextbookAssistantTranslateResponseBodyData
from ._get_aiteacher_expansion_dialogue_suggestion_request import GetAITeacherExpansionDialogueSuggestionRequestDialogueTasks
from ._get_aiteacher_expansion_dialogue_suggestion_request import GetAITeacherExpansionDialogueSuggestionRequestRecords
from ._get_aiteacher_expansion_dialogue_suggestion_request import GetAITeacherExpansionDialogueSuggestionRequestRoleInfo
from ._get_aiteacher_expansion_dialogue_suggestion_response_body import GetAITeacherExpansionDialogueSuggestionResponseBodyData
from ._get_aiteacher_sync_dialogue_suggestion_request import GetAITeacherSyncDialogueSuggestionRequestDialogueTasks
from ._get_aiteacher_sync_dialogue_suggestion_request import GetAITeacherSyncDialogueSuggestionRequestRecords
from ._get_aiteacher_sync_dialogue_suggestion_response_body import GetAITeacherSyncDialogueSuggestionResponseBodyData
from ._get_textbook_assistant_token_response_body import GetTextbookAssistantTokenResponseBodyData
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyDataQuestionList
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyDataSceneList
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyDataSentenceList
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyDataTheme
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyDataTopic
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyDataWordList
from ._list_textbook_assistant_article_details_response_body import ListTextbookAssistantArticleDetailsResponseBodyData
from ._list_textbook_assistant_articles_response_body import ListTextbookAssistantArticlesResponseBodyData
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeTopic
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSectionTopic
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSection
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitTopic
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnit
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTree
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyDataEditionInfo
from ._list_textbook_assistant_book_directories_response_body import ListTextbookAssistantBookDirectoriesResponseBodyData
from ._list_textbook_assistant_books_response_body import ListTextbookAssistantBooksResponseBodyDataBookList
from ._list_textbook_assistant_books_response_body import ListTextbookAssistantBooksResponseBodyDataPaginationData
from ._list_textbook_assistant_books_response_body import ListTextbookAssistantBooksResponseBodyData
from ._list_textbook_assistant_grade_volumes_response_body import ListTextbookAssistantGradeVolumesResponseBodyDataGradeVolumes
from ._list_textbook_assistant_grade_volumes_response_body import ListTextbookAssistantGradeVolumesResponseBodyData
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyDataRoleList
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyDataSceneTaskList
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyDataSentenceList
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyDataTheme
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyDataTopic
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyDataWordList
from ._list_textbook_assistant_scene_details_response_body import ListTextbookAssistantSceneDetailsResponseBodyData
from ._model_router_create_billing_rule_response_body import ModelRouterCreateBillingRuleResponseBodyData
from ._model_router_query_api_key_list_response_body import ModelRouterQueryApiKeyListResponseBodyData
from ._model_router_query_billing_rule_list_response_body import ModelRouterQueryBillingRuleListResponseBodyDataList
from ._model_router_query_billing_rule_list_response_body import ModelRouterQueryBillingRuleListResponseBodyData
from ._model_router_query_client_discount_logs_response_body import ModelRouterQueryClientDiscountLogsResponseBodyData
from ._model_router_query_client_list_response_body import ModelRouterQueryClientListResponseBodyData
from ._model_router_query_conversation_list_response_body import ModelRouterQueryConversationListResponseBodyData
from ._model_router_query_model_list_response_body import ModelRouterQueryModelListResponseBodyData
from ._model_router_query_nacos_providers_response_body import ModelRouterQueryNacosProvidersResponseBodyDataModelsExtensions
from ._model_router_query_nacos_providers_response_body import ModelRouterQueryNacosProvidersResponseBodyDataModels
from ._model_router_query_nacos_providers_response_body import ModelRouterQueryNacosProvidersResponseBodyData
from ._model_router_query_nacos_tags_response_body import ModelRouterQueryNacosTagsResponseBodyData
from ._model_router_query_observation_logs_response_body import ModelRouterQueryObservationLogsResponseBodyData
from ._model_router_update_billing_rule_response_body import ModelRouterUpdateBillingRuleResponseBodyData
from ._personalized_text_to_image_add_inference_job_response_body import PersonalizedTextToImageAddInferenceJobResponseBodyData
from ._personalized_text_to_image_query_pre_model_inference_job_info_response_body import PersonalizedTextToImageQueryPreModelInferenceJobInfoResponseBodyData
from ._personalizedtxt_2img_add_inference_job_response_body import Personalizedtxt2imgAddInferenceJobResponseBodyData
from ._personalizedtxt_2img_add_model_train_job_response_body import Personalizedtxt2imgAddModelTrainJobResponseBodyDataInferenceJobList
from ._personalizedtxt_2img_add_model_train_job_response_body import Personalizedtxt2imgAddModelTrainJobResponseBodyData
from ._personalizedtxt_2img_query_inference_job_info_response_body import Personalizedtxt2imgQueryInferenceJobInfoResponseBodyData
from ._personalizedtxt_2img_query_model_train_job_list_response_body import Personalizedtxt2imgQueryModelTrainJobListResponseBodyDataInferenceJobList
from ._personalizedtxt_2img_query_model_train_job_list_response_body import Personalizedtxt2imgQueryModelTrainJobListResponseBodyData
from ._personalizedtxt_2img_query_model_train_status_response_body import Personalizedtxt2imgQueryModelTrainStatusResponseBodyData
from ._query_application_access_id_response_body import QueryApplicationAccessIdResponseBodyData
from ._query_project_response_body import QueryProjectResponseBodyDataProjectAppsApplicationAccessIds
from ._query_project_response_body import QueryProjectResponseBodyDataProjectApps
from ._query_project_response_body import QueryProjectResponseBodyDataProjectSDK
from ._query_project_response_body import QueryProjectResponseBodyData
from ._query_project_list_response_body import QueryProjectListResponseBodyDataProjectAppsApplicationAccessIds
from ._query_project_list_response_body import QueryProjectListResponseBodyDataProjectApps
from ._query_project_list_response_body import QueryProjectListResponseBodyDataProjectSDK
from ._query_project_list_response_body import QueryProjectListResponseBodyData
from ._update_project_response_body import UpdateProjectResponseBodyDataProjectAppsApplicationAccessIds
from ._update_project_response_body import UpdateProjectResponseBodyDataProjectApps
from ._update_project_response_body import UpdateProjectResponseBodyDataProjectSDK
from ._update_project_response_body import UpdateProjectResponseBodyData

__all__ = [
    AliyunConsoleServiceInfoDTO,
    ApiKeyCreateCmd,
    ApiKeyDTO,
    ApiKeyDecryptedDTO,
    ApiKeyListQry,
    ApiKeyUpdateCmd,
    BillingCostBreakdownRespDTO,
    BillingCostBreakdownRowDTO,
    ClientCreateCmd,
    ClientDTO,
    ClientListQry,
    ClientTreeDTO,
    ClientUpdateCmd,
    ConversationCreateCmd,
    ConversationDTO,
    ConversationListQry,
    ConversationUpdateCmd,
    CostModelDetailRespDTO,
    CostModelDetailRowDTO,
    CostQueryModelsDTO,
    CostQueryTrendDTO,
    CostTabDTO,
    MetricDefRespDTO,
    MetricKVPairDTO,
    MetricValueDTO,
    ModelCreateCmd,
    ModelDTO,
    ModelListQry,
    ModelMetricsDTO,
    ModelRowDTO,
    ModelUpdateCmd,
    ObservationChartsDTO,
    ObservationLogListQry,
    ObservationQry,
    OpenApiMultiResponse,
    OpenApiSingleResponse,
    OralEvaluationStatisticsCallsCountRequest,
    OralEvaluationStatisticsCallsCountResponse,
    OralEvaluationStatisticsConcurrentCountRequest,
    OralEvaluationStatisticsConcurrentCountResponse,
    OralEvaluationStatisticsErrorCountRequest,
    OralEvaluationStatisticsErrorCountResponse,
    OrgInitResultDTO,
    PaidResourceDTO,
    PaidResourceQry,
    Personalizedtxt2imgAddInferenceJobCmd,
    Personalizedtxt2imgAddModelTrainJobCmd,
    Personalizedtxt2imgInferenceJobInfoDTO,
    Personalizedtxt2imgModelTrainJobInfoDTO,
    RequestLogDTO,
    RequestLogListQry,
    TimeSeriesPointDTO,
    TrendPointDTO,
    UsageBreakdownRespDTO,
    UsageBreakdownRowDTO,
    UsageInfoDTO,
    AITeacherExpansionPracticeTaskGenerateRequest,
    AITeacherExpansionPracticeTaskGenerateResponseBody,
    AITeacherExpansionPracticeTaskGenerateResponse,
    AITeacherSyncPracticeTaskGenerateRequest,
    AITeacherSyncPracticeTaskGenerateResponseBody,
    AITeacherSyncPracticeTaskGenerateResponse,
    AliyunConsoleOpenApiQueryAliyunConsoleServcieListResponseBody,
    AliyunConsoleOpenApiQueryAliyunConsoleServcieListResponse,
    AliyunConsoleOpenApiQueryAliyunConsoleServiceListResponseBody,
    AliyunConsoleOpenApiQueryAliyunConsoleServiceListResponse,
    AliyunConsoleOpenApiQueryPaidResourceRequest,
    AliyunConsoleOpenApiQueryPaidResourceResponseBody,
    AliyunConsoleOpenApiQueryPaidResourceResponse,
    CountOralEvaluationStatisticsCallsRequest,
    CountOralEvaluationStatisticsCallsResponseBody,
    CountOralEvaluationStatisticsCallsResponse,
    CountOralEvaluationStatisticsConcurrentRequest,
    CountOralEvaluationStatisticsConcurrentResponseBody,
    CountOralEvaluationStatisticsConcurrentResponse,
    CountOralEvaluationStatisticsErrorRequest,
    CountOralEvaluationStatisticsErrorResponseBody,
    CountOralEvaluationStatisticsErrorResponse,
    CreateAccessWarrantRequest,
    CreateAccessWarrantResponseBody,
    CreateAccessWarrantResponse,
    CreateProjectRequest,
    CreateProjectResponseBody,
    CreateProjectResponse,
    ExecuteAITeacherChineseCompositionTutoringWorkflowRunRequest,
    ExecuteAITeacherChineseCompositionTutoringWorkflowRunResponseBody,
    ExecuteAITeacherChineseCompositionTutoringWorkflowRunResponse,
    ExecuteAITeacherEnglishCompositionTutoringWorkflowRunRequest,
    ExecuteAITeacherEnglishCompositionTutoringWorkflowRunResponseBody,
    ExecuteAITeacherEnglishCompositionTutoringWorkflowRunResponse,
    ExecuteAITeacherEnglishParaphraseChatMessageRequest,
    ExecuteAITeacherEnglishParaphraseChatMessageResponseBody,
    ExecuteAITeacherEnglishParaphraseChatMessageResponse,
    ExecuteAITeacherExpansionDialogueRequest,
    ExecuteAITeacherExpansionDialogueResponseBody,
    ExecuteAITeacherExpansionDialogueResponse,
    ExecuteAITeacherExpansionDialogueRefineRequest,
    ExecuteAITeacherExpansionDialogueRefineResponseBody,
    ExecuteAITeacherExpansionDialogueRefineResponse,
    ExecuteAITeacherExpansionDialogueTranslateRequest,
    ExecuteAITeacherExpansionDialogueTranslateResponseBody,
    ExecuteAITeacherExpansionDialogueTranslateResponse,
    ExecuteAITeacherGrammarCheckRequest,
    ExecuteAITeacherGrammarCheckResponseBody,
    ExecuteAITeacherGrammarCheckResponse,
    ExecuteAITeacherSyncDialogueRequest,
    ExecuteAITeacherSyncDialogueResponseBody,
    ExecuteAITeacherSyncDialogueResponse,
    ExecuteAITeacherSyncDialogueTranslateRequest,
    ExecuteAITeacherSyncDialogueTranslateResponseBody,
    ExecuteAITeacherSyncDialogueTranslateResponse,
    ExecuteTextbookAssistantDialogueRequest,
    ExecuteTextbookAssistantDialogueResponseBody,
    ExecuteTextbookAssistantDialogueResponse,
    ExecuteTextbookAssistantDifficultyRequest,
    ExecuteTextbookAssistantDifficultyResponseBody,
    ExecuteTextbookAssistantDifficultyResponse,
    ExecuteTextbookAssistantGrammarCheckRequest,
    ExecuteTextbookAssistantGrammarCheckResponseBody,
    ExecuteTextbookAssistantGrammarCheckResponse,
    ExecuteTextbookAssistantRefineByContextRequest,
    ExecuteTextbookAssistantRefineByContextResponseBody,
    ExecuteTextbookAssistantRefineByContextResponse,
    ExecuteTextbookAssistantRetryConversationRequest,
    ExecuteTextbookAssistantRetryConversationResponseBody,
    ExecuteTextbookAssistantRetryConversationResponse,
    ExecuteTextbookAssistantSseDialogueRequest,
    ExecuteTextbookAssistantSseDialogueResponseBody,
    ExecuteTextbookAssistantSseDialogueResponse,
    ExecuteTextbookAssistantStartConversationRequest,
    ExecuteTextbookAssistantStartConversationResponseBody,
    ExecuteTextbookAssistantStartConversationResponse,
    ExecuteTextbookAssistantSuggestionRequest,
    ExecuteTextbookAssistantSuggestionResponseBody,
    ExecuteTextbookAssistantSuggestionResponse,
    ExecuteTextbookAssistantTranslateRequest,
    ExecuteTextbookAssistantTranslateResponseBody,
    ExecuteTextbookAssistantTranslateResponse,
    GetAITeacherExpansionDialogueSuggestionRequest,
    GetAITeacherExpansionDialogueSuggestionResponseBody,
    GetAITeacherExpansionDialogueSuggestionResponse,
    GetAITeacherSyncDialogueSuggestionRequest,
    GetAITeacherSyncDialogueSuggestionResponseBody,
    GetAITeacherSyncDialogueSuggestionResponse,
    GetTextbookAssistantTokenRequest,
    GetTextbookAssistantTokenResponseBody,
    GetTextbookAssistantTokenResponse,
    ListTextbookAssistantArticleDetailsRequest,
    ListTextbookAssistantArticleDetailsResponseBody,
    ListTextbookAssistantArticleDetailsResponse,
    ListTextbookAssistantArticlesRequest,
    ListTextbookAssistantArticlesResponseBody,
    ListTextbookAssistantArticlesResponse,
    ListTextbookAssistantBookDirectoriesRequest,
    ListTextbookAssistantBookDirectoriesResponseBody,
    ListTextbookAssistantBookDirectoriesResponse,
    ListTextbookAssistantBooksRequest,
    ListTextbookAssistantBooksResponseBody,
    ListTextbookAssistantBooksResponse,
    ListTextbookAssistantGradeVolumesRequest,
    ListTextbookAssistantGradeVolumesResponseBody,
    ListTextbookAssistantGradeVolumesResponse,
    ListTextbookAssistantSceneDetailsRequest,
    ListTextbookAssistantSceneDetailsResponseBody,
    ListTextbookAssistantSceneDetailsResponse,
    ModelRouterBillingCostTabsRequest,
    ModelRouterBillingCostTabsResponseBody,
    ModelRouterBillingCostTabsResponse,
    ModelRouterChatCompletionsRequest,
    ModelRouterChatCompletionsResponseBody,
    ModelRouterChatCompletionsResponse,
    ModelRouterCopyApiKeyResponseBody,
    ModelRouterCopyApiKeyResponse,
    ModelRouterCreateApiKeyRequest,
    ModelRouterCreateApiKeyResponseBody,
    ModelRouterCreateApiKeyResponse,
    ModelRouterCreateBillingRuleRequest,
    ModelRouterCreateBillingRuleResponseBody,
    ModelRouterCreateBillingRuleResponse,
    ModelRouterCreateClientRequest,
    ModelRouterCreateClientResponseBody,
    ModelRouterCreateClientResponse,
    ModelRouterCreateConversationRequest,
    ModelRouterCreateConversationResponseBody,
    ModelRouterCreateConversationResponse,
    ModelRouterCreateModelRequest,
    ModelRouterCreateModelResponseBody,
    ModelRouterCreateModelResponse,
    ModelRouterDeleteApiKeyResponseBody,
    ModelRouterDeleteApiKeyResponse,
    ModelRouterDeleteClientResponseBody,
    ModelRouterDeleteClientResponse,
    ModelRouterDeleteConversationResponseBody,
    ModelRouterDeleteConversationResponse,
    ModelRouterDeleteModelResponseBody,
    ModelRouterDeleteModelResponse,
    ModelRouterQueryApiKeyResponseBody,
    ModelRouterQueryApiKeyResponse,
    ModelRouterQueryApiKeyListRequest,
    ModelRouterQueryApiKeyListResponseBody,
    ModelRouterQueryApiKeyListResponse,
    ModelRouterQueryBillingCostBreakdownRequest,
    ModelRouterQueryBillingCostBreakdownResponseBody,
    ModelRouterQueryBillingCostBreakdownResponse,
    ModelRouterQueryBillingRuleListRequest,
    ModelRouterQueryBillingRuleListResponseBody,
    ModelRouterQueryBillingRuleListResponse,
    ModelRouterQueryClientDiscountLogsRequest,
    ModelRouterQueryClientDiscountLogsResponseBody,
    ModelRouterQueryClientDiscountLogsResponse,
    ModelRouterQueryClientListRequest,
    ModelRouterQueryClientListResponseBody,
    ModelRouterQueryClientListResponse,
    ModelRouterQueryClientTreeRequest,
    ModelRouterQueryClientTreeResponseBody,
    ModelRouterQueryClientTreeResponse,
    ModelRouterQueryConversationResponseBody,
    ModelRouterQueryConversationResponse,
    ModelRouterQueryConversationListRequest,
    ModelRouterQueryConversationListResponseBody,
    ModelRouterQueryConversationListResponse,
    ModelRouterQueryCostModelDetailRequest,
    ModelRouterQueryCostModelDetailResponseBody,
    ModelRouterQueryCostModelDetailResponse,
    ModelRouterQueryCostModelListRequest,
    ModelRouterQueryCostModelListResponseBody,
    ModelRouterQueryCostModelListResponse,
    ModelRouterQueryCostOverviewMetricsRequest,
    ModelRouterQueryCostOverviewMetricsResponseBody,
    ModelRouterQueryCostOverviewMetricsResponse,
    ModelRouterQueryCostTrendMetricsRequest,
    ModelRouterQueryCostTrendMetricsResponseBody,
    ModelRouterQueryCostTrendMetricsResponse,
    ModelRouterQueryModelResponseBody,
    ModelRouterQueryModelResponse,
    ModelRouterQueryModelListRequest,
    ModelRouterQueryModelListResponseBody,
    ModelRouterQueryModelListResponse,
    ModelRouterQueryNacosProvidersRequest,
    ModelRouterQueryNacosProvidersResponseBody,
    ModelRouterQueryNacosProvidersResponse,
    ModelRouterQueryNacosTagsRequest,
    ModelRouterQueryNacosTagsResponseBody,
    ModelRouterQueryNacosTagsResponse,
    ModelRouterQueryObservationChartsRequest,
    ModelRouterQueryObservationChartsResponseBody,
    ModelRouterQueryObservationChartsResponse,
    ModelRouterQueryObservationLogsRequest,
    ModelRouterQueryObservationLogsResponseBody,
    ModelRouterQueryObservationLogsResponse,
    ModelRouterQueryObservationMetricsRequest,
    ModelRouterQueryObservationMetricsResponseBody,
    ModelRouterQueryObservationMetricsResponse,
    ModelRouterQueryUsageBreakdownRequest,
    ModelRouterQueryUsageBreakdownResponseBody,
    ModelRouterQueryUsageBreakdownResponse,
    ModelRouterUpdateBillingRuleRequest,
    ModelRouterUpdateBillingRuleResponseBody,
    ModelRouterUpdateBillingRuleResponse,
    ModelRouterUpdateClientRequest,
    ModelRouterUpdateClientResponseBody,
    ModelRouterUpdateClientResponse,
    ModelRouterUpdateConversationRequest,
    ModelRouterUpdateConversationResponseBody,
    ModelRouterUpdateConversationResponse,
    ModelRouterUpdateModelRequest,
    ModelRouterUpdateModelResponseBody,
    ModelRouterUpdateModelResponse,
    PersonalizedTextToImageAddInferenceJobRequest,
    PersonalizedTextToImageAddInferenceJobResponseBody,
    PersonalizedTextToImageAddInferenceJobResponse,
    PersonalizedTextToImageQueryImageAssetRequest,
    PersonalizedTextToImageQueryImageAssetResponse,
    PersonalizedTextToImageQueryPreModelInferenceJobInfoRequest,
    PersonalizedTextToImageQueryPreModelInferenceJobInfoResponseBody,
    PersonalizedTextToImageQueryPreModelInferenceJobInfoResponse,
    Personalizedtxt2imgAddInferenceJobRequest,
    Personalizedtxt2imgAddInferenceJobResponseBody,
    Personalizedtxt2imgAddInferenceJobResponse,
    Personalizedtxt2imgAddModelTrainJobRequest,
    Personalizedtxt2imgAddModelTrainJobResponseBody,
    Personalizedtxt2imgAddModelTrainJobResponse,
    Personalizedtxt2imgQueryImageAssetRequest,
    Personalizedtxt2imgQueryImageAssetResponse,
    Personalizedtxt2imgQueryInferenceJobInfoRequest,
    Personalizedtxt2imgQueryInferenceJobInfoResponseBody,
    Personalizedtxt2imgQueryInferenceJobInfoResponse,
    Personalizedtxt2imgQueryModelTrainJobListResponseBody,
    Personalizedtxt2imgQueryModelTrainJobListResponse,
    Personalizedtxt2imgQueryModelTrainStatusRequest,
    Personalizedtxt2imgQueryModelTrainStatusResponseBody,
    Personalizedtxt2imgQueryModelTrainStatusResponse,
    QueryApplicationAccessIdRequest,
    QueryApplicationAccessIdResponseBody,
    QueryApplicationAccessIdResponse,
    QueryProjectRequest,
    QueryProjectResponseBody,
    QueryProjectResponse,
    QueryProjectListResponseBody,
    QueryProjectListResponse,
    QueryPurchasedServiceResponseBody,
    QueryPurchasedServiceResponse,
    UpdateProjectRequest,
    UpdateProjectResponseBody,
    UpdateProjectResponse,
    ObservationChartsDTOSuccessRate,
    OpenApiMultiResponseDataInferenceJobList,
    OpenApiMultiResponseData,
    OpenApiSingleResponseData,
    OralEvaluationStatisticsCallsCountResponseProjectDataApplicationDataData,
    OralEvaluationStatisticsCallsCountResponseProjectDataApplicationData,
    OralEvaluationStatisticsCallsCountResponseProjectData,
    OralEvaluationStatisticsConcurrentCountResponseProjectDataApplicationDataData,
    OralEvaluationStatisticsConcurrentCountResponseProjectDataApplicationData,
    OralEvaluationStatisticsConcurrentCountResponseProjectData,
    OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataDataData,
    OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataData,
    OralEvaluationStatisticsErrorCountResponseProjectDataApplicationData,
    OralEvaluationStatisticsErrorCountResponseProjectData,
    AITeacherExpansionPracticeTaskGenerateResponseBodyDataRoleSet,
    AITeacherExpansionPracticeTaskGenerateResponseBodyDataTaskContent,
    AITeacherExpansionPracticeTaskGenerateResponseBodyData,
    AITeacherSyncPracticeTaskGenerateResponseBodyDataTaskContent,
    AITeacherSyncPracticeTaskGenerateResponseBodyData,
    AliyunConsoleOpenApiQueryAliyunConsoleServcieListResponseBodyData,
    CreateAccessWarrantResponseBodyData,
    CreateProjectResponseBodyDataProjectAppsApplicationAccessIds,
    CreateProjectResponseBodyDataProjectApps,
    CreateProjectResponseBodyDataProjectSDK,
    CreateProjectResponseBodyData,
    ExecuteAITeacherExpansionDialogueRequestDialogueTasks,
    ExecuteAITeacherExpansionDialogueRequestRecords,
    ExecuteAITeacherExpansionDialogueRequestRoleInfo,
    ExecuteAITeacherExpansionDialogueResponseBodyData,
    ExecuteAITeacherExpansionDialogueRefineRequestDialogueTasks,
    ExecuteAITeacherExpansionDialogueRefineRequestRecords,
    ExecuteAITeacherExpansionDialogueRefineRequestRoleInfo,
    ExecuteAITeacherExpansionDialogueRefineResponseBodyData,
    ExecuteAITeacherExpansionDialogueTranslateRequestDialogueTasks,
    ExecuteAITeacherExpansionDialogueTranslateRequestRecords,
    ExecuteAITeacherExpansionDialogueTranslateRequestRoleInfo,
    ExecuteAITeacherExpansionDialogueTranslateResponseBodyData,
    ExecuteAITeacherGrammarCheckResponseBodyData,
    ExecuteAITeacherSyncDialogueRequestDialogueTasks,
    ExecuteAITeacherSyncDialogueRequestRecords,
    ExecuteAITeacherSyncDialogueResponseBodyData,
    ExecuteAITeacherSyncDialogueTranslateRequestDialogueTasks,
    ExecuteAITeacherSyncDialogueTranslateRequestRecords,
    ExecuteAITeacherSyncDialogueTranslateResponseBodyData,
    ExecuteTextbookAssistantDialogueResponseBodyDataResult,
    ExecuteTextbookAssistantDialogueResponseBodyData,
    ExecuteTextbookAssistantDifficultyResponseBodyDataResult,
    ExecuteTextbookAssistantDifficultyResponseBodyData,
    ExecuteTextbookAssistantGrammarCheckResponseBodyDataResult,
    ExecuteTextbookAssistantGrammarCheckResponseBodyData,
    ExecuteTextbookAssistantRefineByContextResponseBodyDataResult,
    ExecuteTextbookAssistantRefineByContextResponseBodyData,
    ExecuteTextbookAssistantRetryConversationResponseBodyDataResult,
    ExecuteTextbookAssistantRetryConversationResponseBodyData,
    ExecuteTextbookAssistantSseDialogueResponseBodyData,
    ExecuteTextbookAssistantStartConversationResponseBodyDataResult,
    ExecuteTextbookAssistantStartConversationResponseBodyData,
    ExecuteTextbookAssistantSuggestionResponseBodyDataResult,
    ExecuteTextbookAssistantSuggestionResponseBodyData,
    ExecuteTextbookAssistantTranslateResponseBodyDataResult,
    ExecuteTextbookAssistantTranslateResponseBodyData,
    GetAITeacherExpansionDialogueSuggestionRequestDialogueTasks,
    GetAITeacherExpansionDialogueSuggestionRequestRecords,
    GetAITeacherExpansionDialogueSuggestionRequestRoleInfo,
    GetAITeacherExpansionDialogueSuggestionResponseBodyData,
    GetAITeacherSyncDialogueSuggestionRequestDialogueTasks,
    GetAITeacherSyncDialogueSuggestionRequestRecords,
    GetAITeacherSyncDialogueSuggestionResponseBodyData,
    GetTextbookAssistantTokenResponseBodyData,
    ListTextbookAssistantArticleDetailsResponseBodyDataQuestionList,
    ListTextbookAssistantArticleDetailsResponseBodyDataSceneList,
    ListTextbookAssistantArticleDetailsResponseBodyDataSentenceList,
    ListTextbookAssistantArticleDetailsResponseBodyDataTheme,
    ListTextbookAssistantArticleDetailsResponseBodyDataTopic,
    ListTextbookAssistantArticleDetailsResponseBodyDataWordList,
    ListTextbookAssistantArticleDetailsResponseBodyData,
    ListTextbookAssistantArticlesResponseBodyData,
    ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeTopic,
    ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSectionTopic,
    ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitSection,
    ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnitTopic,
    ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTreeUnit,
    ListTextbookAssistantBookDirectoriesResponseBodyDataDirectoryTree,
    ListTextbookAssistantBookDirectoriesResponseBodyDataEditionInfo,
    ListTextbookAssistantBookDirectoriesResponseBodyData,
    ListTextbookAssistantBooksResponseBodyDataBookList,
    ListTextbookAssistantBooksResponseBodyDataPaginationData,
    ListTextbookAssistantBooksResponseBodyData,
    ListTextbookAssistantGradeVolumesResponseBodyDataGradeVolumes,
    ListTextbookAssistantGradeVolumesResponseBodyData,
    ListTextbookAssistantSceneDetailsResponseBodyDataRoleList,
    ListTextbookAssistantSceneDetailsResponseBodyDataSceneTaskList,
    ListTextbookAssistantSceneDetailsResponseBodyDataSentenceList,
    ListTextbookAssistantSceneDetailsResponseBodyDataTheme,
    ListTextbookAssistantSceneDetailsResponseBodyDataTopic,
    ListTextbookAssistantSceneDetailsResponseBodyDataWordList,
    ListTextbookAssistantSceneDetailsResponseBodyData,
    ModelRouterCreateBillingRuleResponseBodyData,
    ModelRouterQueryApiKeyListResponseBodyData,
    ModelRouterQueryBillingRuleListResponseBodyDataList,
    ModelRouterQueryBillingRuleListResponseBodyData,
    ModelRouterQueryClientDiscountLogsResponseBodyData,
    ModelRouterQueryClientListResponseBodyData,
    ModelRouterQueryConversationListResponseBodyData,
    ModelRouterQueryModelListResponseBodyData,
    ModelRouterQueryNacosProvidersResponseBodyDataModelsExtensions,
    ModelRouterQueryNacosProvidersResponseBodyDataModels,
    ModelRouterQueryNacosProvidersResponseBodyData,
    ModelRouterQueryNacosTagsResponseBodyData,
    ModelRouterQueryObservationLogsResponseBodyData,
    ModelRouterUpdateBillingRuleResponseBodyData,
    PersonalizedTextToImageAddInferenceJobResponseBodyData,
    PersonalizedTextToImageQueryPreModelInferenceJobInfoResponseBodyData,
    Personalizedtxt2imgAddInferenceJobResponseBodyData,
    Personalizedtxt2imgAddModelTrainJobResponseBodyDataInferenceJobList,
    Personalizedtxt2imgAddModelTrainJobResponseBodyData,
    Personalizedtxt2imgQueryInferenceJobInfoResponseBodyData,
    Personalizedtxt2imgQueryModelTrainJobListResponseBodyDataInferenceJobList,
    Personalizedtxt2imgQueryModelTrainJobListResponseBodyData,
    Personalizedtxt2imgQueryModelTrainStatusResponseBodyData,
    QueryApplicationAccessIdResponseBodyData,
    QueryProjectResponseBodyDataProjectAppsApplicationAccessIds,
    QueryProjectResponseBodyDataProjectApps,
    QueryProjectResponseBodyDataProjectSDK,
    QueryProjectResponseBodyData,
    QueryProjectListResponseBodyDataProjectAppsApplicationAccessIds,
    QueryProjectListResponseBodyDataProjectApps,
    QueryProjectListResponseBodyDataProjectSDK,
    QueryProjectListResponseBodyData,
    UpdateProjectResponseBodyDataProjectAppsApplicationAccessIds,
    UpdateProjectResponseBodyDataProjectApps,
    UpdateProjectResponseBodyDataProjectSDK,
    UpdateProjectResponseBodyData
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class PersonalizedTextToImageAddInferenceJobRequest(DaraModel):
    def __init__(
        self,
        image_number: int = None,
        image_url: List[str] = None,
        prompt: str = None,
        seed: int = None,
        strength: float = None,
        train_steps: int = None,
    ):
        self.image_number = image_number
        # This parameter is required.
        self.image_url = image_url
        # This parameter is required.
        self.prompt = prompt
        self.seed = seed
        self.strength = strength
        self.train_steps = train_steps

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.image_number is not None:
            result['imageNumber'] = self.image_number

        if self.image_url is not None:
            result['imageUrl'] = self.image_url

        if self.prompt is not None:
            result['prompt'] = self.prompt

        if self.seed is not None:
            result['seed'] = self.seed

        if self.strength is not None:
            result['strength'] = self.strength

        if self.train_steps is not None:
            result['trainSteps'] = self.train_steps

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('imageNumber') is not None:
            self.image_number = m.get('imageNumber')

        if m.get('imageUrl') is not None:
            self.image_url = m.get('imageUrl')

        if m.get('prompt') is not None:
            self.prompt = m.get('prompt')

        if m.get('seed') is not None:
            self.seed = m.get('seed')

        if m.get('strength') is not None:
            self.strength = m.get('strength')

        if m.get('trainSteps') is not None:
            self.train_steps = m.get('trainSteps')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModelRouterQueryBillingRuleListRequest(DaraModel):
    def __init__(
        self,
        active_only: bool = None,
        max_results: int = None,
        model_code: str = None,
        model_id: int = None,
        model_type: str = None,
        next_token: str = None,
        page: int = None,
        page_index: int = None,
        page_size: int = None,
    ):
        self.active_only = active_only
        # maxResults
        self.max_results = max_results
        self.model_code = model_code
        self.model_id = model_id
        self.model_type = model_type
        # nextToken
        self.next_token = next_token
        self.page = page
        self.page_index = page_index
        self.page_size = page_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_only is not None:
            result['activeOnly'] = self.active_only

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.model_code is not None:
            result['modelCode'] = self.model_code

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.page is not None:
            result['page'] = self.page

        if self.page_index is not None:
            result['pageIndex'] = self.page_index

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('activeOnly') is not None:
            self.active_only = m.get('activeOnly')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('modelCode') is not None:
            self.model_code = m.get('modelCode')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('page') is not None:
            self.page = m.get('page')

        if m.get('pageIndex') is not None:
            self.page_index = m.get('pageIndex')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class BillingCostBreakdownRowDTO(DaraModel):
    def __init__(
        self,
        billing_type: str = None,
        client_id: int = None,
        client_name: str = None,
        model_code: str = None,
        model_id: int = None,
        model_name: str = None,
        model_type: str = None,
        payable_amount: float = None,
        summary_time: int = None,
    ):
        self.billing_type = billing_type
        self.client_id = client_id
        self.client_name = client_name
        self.model_code = model_code
        self.model_id = model_id
        self.model_name = model_name
        self.model_type = model_type
        self.payable_amount = payable_amount
        self.summary_time = summary_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.billing_type is not None:
            result['billingType'] = self.billing_type

        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.client_name is not None:
            result['clientName'] = self.client_name

        if self.model_code is not None:
            result['modelCode'] = self.model_code

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.model_name is not None:
            result['modelName'] = self.model_name

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.payable_amount is not None:
            result['payableAmount'] = self.payable_amount

        if self.summary_time is not None:
            result['summaryTime'] = self.summary_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('billingType') is not None:
            self.billing_type = m.get('billingType')

        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('clientName') is not None:
            self.client_name = m.get('clientName')

        if m.get('modelCode') is not None:
            self.model_code = m.get('modelCode')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('modelName') is not None:
            self.model_name = m.get('modelName')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('payableAmount') is not None:
            self.payable_amount = m.get('payableAmount')

        if m.get('summaryTime') is not None:
            self.summary_time = m.get('summaryTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListTextbookAssistantArticlesRequest(DaraModel):
    def __init__(
        self,
        auth_token: str = None,
        directory_id: str = None,
    ):
        # This parameter is required.
        self.auth_token = auth_token
        # This parameter is required.
        self.directory_id = directory_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_token is not None:
            result['authToken'] = self.auth_token

        if self.directory_id is not None:
            result['directoryId'] = self.directory_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('authToken') is not None:
            self.auth_token = m.get('authToken')

        if m.get('directoryId') is not None:
            self.directory_id = m.get('directoryId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ExecuteAITeacherChineseCompositionTutoringWorkflowRunRequest(DaraModel):
    def __init__(
        self,
        essay_outline: str = None,
        essay_requirements: str = None,
        essay_topic: str = None,
        essay_type: str = None,
        essay_word_count: int = None,
        grade: int = None,
        response_mode: str = None,
        user_id: str = None,
    ):
        self.essay_outline = essay_outline
        # This parameter is required.
        self.essay_requirements = essay_requirements
        # This parameter is required.
        self.essay_topic = essay_topic
        # This parameter is required.
        self.essay_type = essay_type
        self.essay_word_count = essay_word_count
        # This parameter is required.
        self.grade = grade
        # This parameter is required.
        self.response_mode = response_mode
        # This parameter is required.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.essay_outline is not None:
            result['essayOutline'] = self.essay_outline

        if self.essay_requirements is not None:
            result['essayRequirements'] = self.essay_requirements

        if self.essay_topic is not None:
            result['essayTopic'] = self.essay_topic

        if self.essay_type is not None:
            result['essayType'] = self.essay_type

        if self.essay_word_count is not None:
            result['essayWordCount'] = self.essay_word_count

        if self.grade is not None:
            result['grade'] = self.grade

        if self.response_mode is not None:
            result['responseMode'] = self.response_mode

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('essayOutline') is not None:
            self.essay_outline = m.get('essayOutline')

        if m.get('essayRequirements') is not None:
            self.essay_requirements = m.get('essayRequirements')

        if m.get('essayTopic') is not None:
            self.essay_topic = m.get('essayTopic')

        if m.get('essayType') is not None:
            self.essay_type = m.get('essayType')

        if m.get('essayWordCount') is not None:
            self.essay_word_count = m.get('essayWordCount')

        if m.get('grade') is not None:
            self.grade = m.get('grade')

        if m.get('responseMode') is not None:
            self.response_mode = m.get('responseMode')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class RequestLogDTO(DaraModel):
    def __init__(
        self,
        api_key_id: int = None,
        client_id: int = None,
        client_uuid: str = None,
        completion_tokens: int = None,
        delete_tag: int = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        model_code: str = None,
        model_id: int = None,
        model_name: str = None,
        model_type: str = None,
        prompt_tokens: int = None,
        request_body: str = None,
        request_id: str = None,
        request_time: str = None,
        response_body: str = None,
        response_time_ms: int = None,
        status: str = None,
        status_code: int = None,
        symbol: str = None,
        total_tokens: int = None,
        usage: main_models.UsageInfoDTO = None,
    ):
        self.api_key_id = api_key_id
        self.client_id = client_id
        self.client_uuid = client_uuid
        self.completion_tokens = completion_tokens
        self.delete_tag = delete_tag
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.id = id
        self.model_code = model_code
        self.model_id = model_id
        self.model_name = model_name
        self.model_type = model_type
        self.prompt_tokens = prompt_tokens
        self.request_body = request_body
        self.request_id = request_id
        self.request_time = request_time
        self.response_body = response_body
        self.response_time_ms = response_time_ms
        self.status = status
        self.status_code = status_code
        self.symbol = symbol
        self.total_tokens = total_tokens
        self.usage = usage

    def validate(self):
        if self.usage:
            self.usage.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.api_key_id is not None:
            result['apiKeyId'] = self.api_key_id

        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.client_uuid is not None:
            result['clientUuid'] = self.client_uuid

        if self.completion_tokens is not None:
            result['completionTokens'] = self.completion_tokens

        if self.delete_tag is not None:
            result['deleteTag'] = self.delete_tag

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.id is not None:
            result['id'] = self.id

        if self.model_code is not None:
            result['modelCode'] = self.model_code

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.model_name is not None:
            result['modelName'] = self.model_name

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.prompt_tokens is not None:
            result['promptTokens'] = self.prompt_tokens

        if self.request_body is not None:
            result['requestBody'] = self.request_body

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.request_time is not None:
            result['requestTime'] = self.request_time

        if self.response_body is not None:
            result['responseBody'] = self.response_body

        if self.response_time_ms is not None:
            result['responseTimeMs'] = self.response_time_ms

        if self.status is not None:
            result['status'] = self.status

        if self.status_code is not None:
            result['statusCode'] = self.status_code

        if self.symbol is not None:
            result['symbol'] = self.symbol

        if self.total_tokens is not None:
            result['totalTokens'] = self.total_tokens

        if self.usage is not None:
            result['usage'] = self.usage.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('apiKeyId') is not None:
            self.api_key_id = m.get('apiKeyId')

        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('clientUuid') is not None:
            self.client_uuid = m.get('clientUuid')

        if m.get('completionTokens') is not None:
            self.completion_tokens = m.get('completionTokens')

        if m.get('deleteTag') is not None:
            self.delete_tag = m.get('deleteTag')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('modelCode') is not None:
            self.model_code = m.get('modelCode')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('modelName') is not None:
            self.model_name = m.get('modelName')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('promptTokens') is not None:
            self.prompt_tokens = m.get('promptTokens')

        if m.get('requestBody') is not None:
            self.request_body = m.get('requestBody')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('requestTime') is not None:
            self.request_time = m.get('requestTime')

        if m.get('responseBody') is not None:
            self.response_body = m.get('responseBody')

        if m.get('responseTimeMs') is not None:
            self.response_time_ms = m.get('responseTimeMs')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')

        if m.get('symbol') is not None:
            self.symbol = m.get('symbol')

        if m.get('totalTokens') is not None:
            self.total_tokens = m.get('totalTokens')

        if m.get('usage') is not None:
            temp_model = main_models.UsageInfoDTO()
            self.usage = temp_model.from_map(m.get('usage'))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Any

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ModelRouterCreateBillingRuleResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.ModelRouterCreateBillingRuleResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.ModelRouterCreateBillingRuleResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class ModelRouterCreateBillingRuleResponseBodyData(DaraModel):
    def __init__(
        self,
        billing_type: str = None,
        delete_tag: int = None,
        effective_time: str = None,
        expire_time: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        model_code: str = None,
        model_id: int = None,
        model_name: str = None,
        model_type: str = None,
        pricing_config: Any = None,
        symbol: str = None,
        version: int = None,
    ):
        self.billing_type = billing_type
        self.delete_tag = delete_tag
        self.effective_time = effective_time
        self.expire_time = expire_time
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.id = id
        self.model_code = model_code
        self.model_id = model_id
        self.model_name = model_name
        self.model_type = model_type
        self.pricing_config = pricing_config
        self.symbol = symbol
        self.version = version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.billing_type is not None:
            result['billingType'] = self.billing_type

        if self.delete_tag is not None:
            result['deleteTag'] = self.delete_tag

        if self.effective_time is not None:
            result['effectiveTime'] = self.effective_time

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.id is not None:
            result['id'] = self.id

        if self.model_code is not None:
            result['modelCode'] = self.model_code

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.model_name is not None:
            result['modelName'] = self.model_name

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.pricing_config is not None:
            result['pricingConfig'] = self.pricing_config

        if self.symbol is not None:
            result['symbol'] = self.symbol

        if self.version is not None:
            result['version'] = self.version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('billingType') is not None:
            self.billing_type = m.get('billingType')

        if m.get('deleteTag') is not None:
            self.delete_tag = m.get('deleteTag')

        if m.get('effectiveTime') is not None:
            self.effective_time = m.get('effectiveTime')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('modelCode') is not None:
            self.model_code = m.get('modelCode')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('modelName') is not None:
            self.model_name = m.get('modelName')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('pricingConfig') is not None:
            self.pricing_config = m.get('pricingConfig')

        if m.get('symbol') is not None:
            self.symbol = m.get('symbol')

        if m.get('version') is not None:
            self.version = m.get('version')

        return self

